import React, { useState, useEffect } from 'react';
import { pb } from '../../services/pocketbaseService'; // Import pb for create/update

const AchievementForm = ({ onSuccess, onCancel, achievementToEdit }) => {
  const [formData, setFormData] = useState({
    title: '',
    description: '',
    xp_reward: 0,
    // Add other fields like icon if you have them
  });
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);

  useEffect(() => {
    if (achievementToEdit) {
      setFormData({
        title: achievementToEdit.title,
        description: achievementToEdit.description,
        xp_reward: achievementToEdit.xp_reward,
        // Load other fields here
      });
    } else {
       // Reset form if creating a new achievement
       setFormData({
            title: '',
            description: '',
            xp_reward: 0,
       });
    }
  }, [achievementToEdit]);

  const handleChange = (e) => {
    const { name, value, type } = e.target;
    setFormData({
      ...formData,
      [name]: type === 'number' ? parseInt(value, 10) || 0 : value, // Parse number input
    });
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setLoading(true);
    setError(null);

    try {
      let record;
      if (achievementToEdit) {
        // Update existing achievement
        console.log('PocketBase: Updating achievement:', achievementToEdit.id, formData);
        record = await pb.collection('achievements').update(achievementToEdit.id, formData);
        console.log('PocketBase: Achievement updated:', record);
      } else {
        // Create new achievement
        console.log('PocketBase: Creating achievement:', formData);
        record = await pb.collection('achievements').create(formData);
        console.log('PocketBase: Achievement created:', record);
      }
      onSuccess(); // Call success callback
    } catch (err) {
      console.error('Error saving achievement:', err);
      setError(err.message);
    } finally {
      setLoading(false);
    }
  };

  return (
    <form onSubmit={handleSubmit} className="p-4">
      {error && (
        <div className="bg-red-500/10 border border-red-500/20 text-red-500 p-3 rounded-lg mb-4 text-sm">
          {error}
        </div>
      )}

      <div className="mb-4">
        <label htmlFor="title" className="block text-sm font-medium text-campfire-ash mb-1">Название</label>
        <input
          type="text"
          id="title"
          name="title"
          value={formData.title}
          onChange={handleChange}
          required
          className="w-full px-3 py-2 bg-campfire-dark text-campfire-light border border-campfire-ash/30 rounded-md focus:outline-none focus:ring-campfire-amber focus:border-campfire-amber"
        />
      </div>

      <div className="mb-4">
        <label htmlFor="description" className="block text-sm font-medium text-campfire-ash mb-1">Описание</label>
        <textarea
          id="description"
          name="description"
          value={formData.description}
          onChange={handleChange}
          required
          rows="3"
          className="w-full px-3 py-2 bg-campfire-dark text-campfire-light border border-campfire-ash/30 rounded-md focus:outline-none focus:ring-campfire-amber focus:border-campfire-amber"
        ></textarea>
      </div>

      <div className="mb-4">
        <label htmlFor="xp_reward" className="block text-sm font-medium text-campfire-ash mb-1">Награда XP</label>
        <input
          type="number"
          id="xp_reward"
          name="xp_reward"
          value={formData.xp_reward}
          onChange={handleChange}
          required
          min="0"
          className="w-full px-3 py-2 bg-campfire-dark text-campfire-light border border-campfire-ash/30 rounded-md focus:outline-none focus:ring-campfire-amber focus:border-campfire-amber"
        />
      </div>

      {/* Add file input for icon if needed */}
      {/*
      <div className="mb-4">
          <label htmlFor="icon" className="block text-sm font-medium text-campfire-ash mb-1">Иконка</label>
          <input
              type="file"
              id="icon"
              name="icon"
              onChange={handleFileChange} // You'll need a separate handler for files
              className="w-full text-campfire-light text-sm file:mr-4 file:py-2 file:px-4 file:rounded-full file:border-0 file:text-sm file:font-semibold file:bg-campfire-amber file:text-campfire-dark hover:file:bg-campfire-light"
          />
      </div>
      */}


      <div className="flex justify-end space-x-4 mt-6">
        <button
          type="button"
          onClick={onCancel}
          className="px-4 py-2 bg-campfire-charcoal text-campfire-light rounded-md hover:bg-campfire-ash/30 transition-colors"
          disabled={loading}
        >
          Отмена
        </button>
        <button
          type="submit"
          className="btn-primary"
          disabled={loading}
        >
          {loading ? 'Сохранение...' : achievementToEdit ? 'Сохранить изменения' : 'Создать достижение'}
        </button>
      </div>
    </form>
  );
};

export default AchievementForm;
