import React, { createContext, useContext, useState } from 'react';
import { createMedia, validateMediaData, formatMediaData } from '../services/pocketbaseService'; // Import from pocketbaseService, including validation/formatting

const MediaContext = createContext();

export const useMedia = () => {
  const context = useContext(MediaContext);
  if (!context) {
    throw new Error('useMedia must be used within a MediaProvider');
  }
  return context;
};

export const MediaProvider = ({ children }) => {
  // Removed searchResults and selectedMedia states as search/details logic is likely handled elsewhere now
  const [loading, setLoading] = useState(false);
  const [error, setError] = useState(null);

  // Removed handleSearch and handleSelectMedia as they likely relied on the removed mediaService functionality
  // If external search/details is needed, this logic will need to be reimplemented using a different service/API.

  const handleCreateMedia = async (mediaData) => {
    try {
      setLoading(true);
      setError(null);

      console.log('MediaContext: Попытка создания медиа:', mediaData);

      // Валидация данных (теперь из pocketbaseService)
      const errors = validateMediaData(mediaData);
      if (errors.length > 0) {
        console.error('MediaContext: Ошибки валидации:', errors);
        throw new Error('Ошибки валидации:\n' + errors.join('\n'));
      }
      console.log('MediaContext: Валидация данных успешна.');


      // Форматирование данных (теперь из pocketbaseService)
      const formattedData = formatMediaData(mediaData);
      console.log('MediaContext: Данные отформатированы для PocketBase:', formattedData);


      // Создание медиа через PocketBase
      const newMedia = await createMedia(formattedData);
      console.log('MediaContext: Медиа успешно создано:', newMedia);
      return newMedia;
    } catch (error) {
      console.error('MediaContext: Ошибка при создании медиа:', error);
      // PocketBase errors might have a response structure
      if (error.response && error.response.data) {
         console.error('MediaContext: PocketBase Response data:', error.response.data);
         // Attempt to extract specific error messages from PocketBase response
         const pbErrors = Object.values(error.response.data).map(err => err.message).join('\n');
         setError('Ошибка при создании медиа:\n' + pbErrors || error.message || 'Неизвестная ошибка');
      } else {
         setError(error.message || 'Ошибка при создании медиа');
      }
      throw error; // Re-throw to allow calling component to handle
    } finally {
      setLoading(false);
    }
  };

  const value = {
    // Removed searchResults, selectedMedia
    loading,
    error,
    // Removed handleSearch, handleSelectMedia
    handleCreateMedia
  };

  return (
    <MediaContext.Provider value={value}>
      {children}
    </MediaContext.Provider>
  );
};
