import React, { useState, useEffect } from 'react';
import { useNavigate, Link } from 'react-router-dom';
import { useAuth } from '../contexts/AuthContext'; // Import useAuth

const LoginPage = () => {
  const [login, setLogin] = useState('');
  const [password, setPassword] = useState('');
  const [error, setError] = useState('');
  const [loading, setLoading] = useState(false);
  const navigate = useNavigate();

  const { user, userProfile, loading: authLoading, signIn, isInitialized } = useAuth(); // Get isInitialized

  console.log('LoginPage: Rendering. State:', { user: !!user, userProfile: !!userProfile, authLoading, isInitialized, componentLoading: loading, componentError: error }); // Add component render log

  useEffect(() => {
    console.log('LoginPage useEffect: Running. State:', { user: !!user, userProfile: !!userProfile, authLoading, isInitialized }); // Add useEffect log
    if (!authLoading && isInitialized) { // Wait for auth to be initialized and not loading
        if (user && userProfile) {
            console.log('LoginPage useEffect: User and profile loaded, redirecting to profile:', userProfile.username);
            navigate(`/profile/${userProfile.username}`);
        } else {
            console.log('LoginPage useEffect: No user and auth initialized, staying on login.');
        }
    } else if (authLoading) {
       console.log('LoginPage useEffect: Auth is loading...');
    } else if (!isInitialized) {
       console.log('LoginPage useEffect: Auth is not initialized...');
    }
  }, [user, userProfile, authLoading, isInitialized, navigate]); // Add isInitialized to dependencies

  const handleSubmit = async (e) => {
    e.preventDefault();
    setError(null);
    setLoading(true);

    try {
        await signIn(login, password);
        navigate('/');
    } catch (err) {
        console.error('Login error:', err);
        setError(err.message);
    } finally {
        setLoading(false);
    }
  };

  // Render loading state based on AuthContext loading
  // Removed the check here to allow the form to render even if auth is loading,
  // relying on the AuthProvider's own loading state handling.
  // This might help diagnose if the component itself is not rendering.
  // if (authLoading || !isInitialized) {
  //    console.log('LoginPage: Rendering initial auth loading state.');
  //    return (
  //       <div className="pt-20 min-h-screen flex items-center justify-center bg-campfire-dark text-campfire-light">
  //          Загрузка авторизации...
  //       </div>
  //    );
  // }

  console.log('LoginPage: Rendering login form.'); // Log before rendering form

  return (
    <div className="min-h-screen bg-campfire-dark pt-20 flex justify-center items-center">
      <div className="w-full max-w-md p-8 bg-campfire-charcoal rounded-lg shadow-lg">
        <h1 className="text-2xl font-bold text-campfire-light mb-6 text-center">Вход</h1>
        {error && (
          <div className="mb-4 p-3 bg-status-error/20 text-status-error rounded-lg text-center">
            {error}
          </div>
        )}
        <form onSubmit={handleSubmit} className="space-y-4">
          <div>
            <label htmlFor="login" className="block text-sm font-medium text-campfire-light mb-1">
              Логин
            </label>
            <input
              type="text"
              id="login"
              value={login}
              onChange={(e) => setLogin(e.target.value)}
              className="input w-full px-3 py-2 bg-campfire-dark text-campfire-light border border-campfire-ash/30 rounded-md focus:outline-none focus:ring-campfire-amber focus:border-campfire-amber transition-colors"
              placeholder="Введите логин"
              required
              autoComplete="username"
            />
          </div>

          <div>
            <label htmlFor="password" className="block text-sm font-medium text-campfire-light mb-1">
              Пароль
            </label>
            <input
              type="password"
              id="password"
              value={password}
              onChange={(e) => setPassword(e.target.value)}
              className="input w-full px-3 py-2 bg-campfire-dark text-campfire-light border border-campfire-ash/30 rounded-md focus:outline-none focus:ring-campfire-amber focus:border-campfire-amber transition-colors"
              placeholder="••••••••"
              required
              autoComplete="current-password"
            />
          </div>

          <button
            type="submit"
            disabled={loading}
            className={`btn-primary w-full ${loading ? "opacity-80 cursor-not-allowed" : ""} transition-colors duration-200`}
          >
            {loading ? (
              <span className="inline-flex items-center">
                <svg
                  className="animate-spin -ml-1 mr-2 h-4 w-4 text-white"
                  xmlns="http://www.w3.org/2000/svg"
                  fill="none"
                  viewBox="0 0 24 24"
                >
                  <circle
                    className="opacity-25"
                    cx="12"
                    cy="12"
                    r="10"
                    stroke="currentColor"
                    strokeWidth="4"
                  ></circle>
                  <path
                    className="opacity-75"
                    fill="currentColor"
                    d="M4 12a8 8 0 018-8V0C5.373 0 0 5.373 0 12h4zm2 5.291A7.962 7.962 0 014 12H0c0 3.042 1.135 5.824 3 7.938l3-2.647z"
                  ></path>
                </svg>
                Входим...
              </span>
            ) : (
              "Войти"
            )}
          </button>
        </form>

        <div className="mt-6 text-center text-sm text-campfire-ash">
          Еще нет аккаунта?{" "}
          <Link
            to="/auth/register"
            className="text-campfire-amber hover:text-campfire-ember font-medium transition-colors"
          >
            Зарегистрироваться
          </Link>
        </div>
      </div>
    </div>
  );
};

export default LoginPage;
