import React, { useEffect, useState, useCallback } from 'react';
import { useParams, Link, useNavigate } from 'react-router-dom'; // Import useNavigate
import {
  pb, // Import pb instance
  getUserProfileByUsername,
  getUserAchievements,
  getReviewsByUserId,
  getFileUrl,
  updateUserProfile, // Note: This is not used for file uploads/deletions in this component
  updateUserShowcase,
  getXpForCurrentLevel,
  getXpForNextLevel,
  getAllAchievements, // Import getAllAchievements
  awardAchievement // Import awardAchievement
} from '../services/pocketbaseService';
import { useAuth } from '../contexts/AuthContext';
import { useProfileActions } from '../contexts/ProfileActionsContext';
import ReviewItem from '../components/reviews/ReviewItem';
import ReviewList from '../components/reviews/ReviewList';
import Modal from '../components/common/Modal';
import { FaEdit, FaCheckCircle, FaRegCircle, FaFire, FaTrophy, FaAward } from 'react-icons/fa'; // Added FaAward
import { mediaTypes } from '../services/pocketbaseService';


const ProfilePage = () => {
  const { username } = useParams();
  const { user: currentUser, userProfile: currentUserProfile, loading: authLoading, isInitialized: authInitialized } = useAuth(); // currentUser is the PocketBase auth model
  const { shouldOpenEditModal, resetEditModalTrigger } = useProfileActions() || {};
  const navigate = useNavigate(); // Initialize useNavigate
  const [profileUser, setProfileUser] = useState(null);
  const [achievements, setAchievements] = useState([]);
  const [reviews, setReviews] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);

  const [isEditingProfile, setIsEditingProfile] = useState(false);
  const [editFormData, setEditFormData] = useState({ description: '', profile_picture: null, banner_picture: null });
  const [profilePictureFile, setProfilePictureFile] = useState(null);
  const [bannerPictureFile, setBannerPictureFile] = useState(null);
  const [deleteProfilePicture, setDeleteProfilePicture] = useState(false);
  const [deleteBannerPicture, setDeleteBannerPicture] = useState(false);
  const [editFormError, setEditFormError] = useState(null);
  const [isSubmittingEdit, setIsSubmittingEdit] = useState(false);

  const [isManagingShowcase, setIsManagingShowcase] = useState(false);
  const [selectedShowcaseReviewIds, setSelectedShowcaseReviewIds] = useState([]);

  // State for Achievement Assignment Modal (New)
  const [isAssigningAchievements, setIsAssigningAchievements] = useState(false);
  const [availableAchievements, setAvailableAchievements] = useState([]); // To fetch list of all achievements
  const [userAchievementIds, setUserAchievementIds] = useState([]); // To track achievements the user already has
  const [selectedAchievementIdsToAssign, setSelectedAchievementIdsToAssign] = useState([]); // To track achievements to assign/remove


  // Determine if the logged-in user is viewing their own profile
  const isOwnProfile = currentUser && profileUser && currentUser.id === profileUser.id;
  // Check if the logged-in user has the 'admin' role
  const isAdmin = currentUser?.role === 'admin';


  const loadProfileData = useCallback(async () => {
      if (!username) {
          setError('Имя пользователя не указано.');
          setLoading(false);
          return;
      }
      try {
          setLoading(true);
          setError(null);

          // Fetch user profile by username, expanding showcase relation
          const userData = await getUserProfileByUsername(username);
          if (!userData) {
              throw new Error('Пользователь не найден.');
          }
          setProfileUser(userData);
          console.log('ProfilePage: User data loaded:', userData);
          console.log('ProfilePage: User showcase data:', userData.showcase, 'expanded:', userData.expand?.showcase);

          // Fetch user's achievements
          const achievementsData = await getUserAchievements(userData.id);
          setAchievements(achievementsData || []);
          console.log('ProfilePage: Achievements loaded:', achievementsData);
          // Store user's current achievement IDs for assignment modal
          setUserAchievementIds(achievementsData.map(ua => ua.achievement_id) || []);


          // Fetch user's reviews
          const reviewsData = await getReviewsByUserId(userData.id);
          setReviews(reviewsData || []);
          console.log('ProfilePage: Reviews loaded:', reviewsData);

          // Initialize showcase selection state for management modal
          setSelectedShowcaseReviewIds(userData.showcase || []);


      } catch (err) {
          console.error('Error loading profile data:', err);
          setError('Не удалось загрузить данные профиля.');
      } finally {
          setLoading(false);
      }
  }, [username]);


  useEffect(() => {
      console.log('ProfilePage mounted or dependencies changed. username:', username, 'currentUser:', !!currentUser, 'authLoading:', authLoading, 'authInitialized:', authInitialized, 'profileUser:', !!profileUser, 'isOwnProfile:', isOwnProfile); // Added profileUser and isOwnProfile to log
      // Wait for auth to be initialized before loading profile data
      if (!authLoading && authInitialized) {
          console.log('ProfilePage useEffect: Auth initialized and not loading. Loading profile data...');
          loadProfileData();
      } else {
          console.log('ProfilePage useEffect: Waiting for auth initialization or loading...');
      }
  }, [username, currentUser, authLoading, authInitialized, loadProfileData]); // Added authInitialized to dependencies


  // Effect to open edit modal if triggered by context (e.g., from Header)
  // This effect should ONLY handle the external trigger and the edit modal.
  // It should NOT interfere with modals opened by buttons on the page itself.
  useEffect(() => {
      console.log('ProfilePage useEffect [shouldOpenEditModal, isOwnProfile, profileUser]: Running for external edit trigger. shouldOpenEditModal:', shouldOpenEditModal, 'isOwnProfile:', isOwnProfile, 'profileUser:', !!profileUser);
      // Check if the trigger is set AND we are viewing the *own* profile AND profileUser data is loaded
      if (shouldOpenEditModal && isOwnProfile && profileUser) {
          console.log('ProfilePage useEffect [shouldOpenEditModal, isOwnProfile, profileUser]: Triggered to open edit modal. Opening modal...');
          handleEditProfile(); // Open the modal
          // Reset the trigger *after* the modal is successfully opened
          resetEditModalTrigger();
      } else if (shouldOpenEditModal && (!isOwnProfile || !profileUser)) {
          // If trigger is set but it's not the own profile or profile data isn't ready,
          // DO NOT reset the trigger immediately. Let the next render/useEffect run
          // when profileUser might be loaded.
          console.log('ProfilePage useEffect [shouldOpenEditModal, isOwnProfile, profileUser]: Trigger set, but not own profile or profile data not ready. Waiting for profile data...');
          // Do nothing here, let the effect potentially run again when profileUser is loaded
      }
      // REMOVED: The else if block that closed modals when shouldOpenEditModal was false.
      // Modals opened by buttons on the page should be closed by their own handlers.
  }, [shouldOpenEditModal, isOwnProfile, profileUser, resetEditModalTrigger]); // Added modal states to dependencies


  // --- Profile Edit Modal Handlers ---
  const handleEditProfile = () => {
      if (!profileUser) return;
      console.log('ProfilePage: Opening edit profile modal.');
      setEditFormData({
          description: profileUser.description || '',
          profile_picture: null,
          banner_picture: null,
      });
      setProfilePictureFile(null);
      setBannerPictureFile(null);
      setDeleteProfilePicture(false);
      setDeleteBannerPicture(false);
      setEditFormError(null);
      setIsEditingProfile(true);
  };

  const handleEditFormChange = (e) => {
      const { name, value } = e.target;
      setEditFormData(prev => ({ ...prev, [name]: value }));
  };

  const handleEditFileChange = (e) => {
      const { name, files } = e.target;
      const file = files?.[0] || null;
      if (name === 'profile_picture') {
          setProfilePictureFile(file);
          if (file) setDeleteProfilePicture(false);
      } else if (name === 'banner_picture') {
          setBannerPictureFile(file);
          if (file) setDeleteBannerPicture(false);
      }
  };

  const handleRemoveExistingPicture = (fieldName) => {
      if (fieldName === 'profile_picture') {
          setDeleteProfilePicture(true);
          setProfilePictureFile(null);
      } else if (fieldName === 'banner_picture') {
          setDeleteBannerPicture(true);
          setBannerPictureFile(null);
      }
  };


  const handleEditFormSubmit = async (e) => {
      e.preventDefault();
      if (!profileUser) return;

      setIsSubmittingEdit(true);
      setEditFormError(null);

      try {
          // Use pb.collection('users').update() with FormData
          const formData = new FormData();
          formData.append('description', editFormData.description);

          if (profilePictureFile) {
              formData.append('profile_picture', profilePictureFile);
          } else if (deleteProfilePicture && profileUser.profile_picture) {
              // To delete an existing file, append the field name with null
              formData.append('profile_picture', null);
          }

          if (bannerPictureFile) {
              formData.append('banner_picture', bannerPictureFile);
          } else if (deleteBannerPicture && profileUser.banner_picture) {
              // To delete an existing file, append the field name with null
              formData.append('banner_picture', null);
          }

          // Use pb instance imported directly
          await pb.collection('users').update(profileUser.id, formData);


          console.log('Profile updated successfully.');
          setIsEditingProfile(false);
          // Refresh the user profile in AuthContext and on the page
          // Assuming refreshUserProfile in AuthContext fetches the latest user record
          // and updates the context state, which will then update profileUser state here.
          // If not, we might need to manually update profileUser state or refetch.
          // Let's call loadProfileData to ensure page data is fresh.
          loadProfileData();


      } catch (err) {
          console.error('Error updating profile:', err);
          // PocketBase validation errors might be in err.response.data.data
          const pbErrorData = err.response?.data?.data;
          let errorMessage = err.message || 'Произошла ошибка при обновлении профиля.';

          if (pbErrorData) {
              // Attempt to format PocketBase validation errors
              errorMessage = Object.entries(pbErrorData)
                  .map(([field, errorInfo]) => `${field}: ${errorInfo.message}`)
                  .join(', ');
          }

          setEditFormError(errorMessage);
      } finally {
          setIsSubmittingEdit(false);
      }
  };

  const handleEditFormCancel = () => {
      setIsEditingProfile(false);
      setEditFormError(null);
  };

  // --- Showcase Management Handlers ---
  const handleManageShowcase = () => {
      if (!profileUser) return;
      console.log('ProfilePage: Opening showcase management modal.'); // Added log
      setSelectedShowcaseReviewIds(profileUser.showcase || []);
      setIsManagingShowcase(true);
  };

  const handleToggleShowcaseReview = (reviewId) => {
      setSelectedShowcaseReviewIds(prev => {
          const isSelected = prev.includes(reviewId);
          if (isSelected) {
              return prev.filter(id => id !== reviewId);
          } else {
              if (prev.length < 3) {
                  return [...prev, reviewId];
              } else {
                  alert('Вы можете выбрать до 3 рецензий для витрины.');
                  return prev;
              }
          }
      });
  };

  const handleSaveShowcase = async () => {
      if (!profileUser) return;
      setIsSubmittingEdit(true);
      setEditFormError(null);

      try {
          // PocketBase update for relation list requires sending the full list of IDs
          // Use pb instance imported directly
          await pb.collection('users').update(profileUser.id, {
              showcase: selectedShowcaseReviewIds
          });

          console.log('Showcase updated successfully.');
          setIsManagingShowcase(false);
          loadProfileData(); // Refresh profile data to show updated showcase

      } catch (err) {
          console.error('Error updating showcase:', err);
          const pbErrorData = err.response?.data?.data;
          let errorMessage = err.message || 'Произошла ошибка при обновлении витрины.';

          if (pbErrorData) {
              errorMessage = Object.entries(pbErrorData)
                  .map(([field, errorInfo]) => `${field}: ${errorInfo.message}`)
                  .join(', ');
          }
          setEditFormError(errorMessage);
      } finally {
          setIsSubmittingEdit(false);
      }
  };

  const handleCancelShowcase = () => {
      setIsManagingShowcase(false);
      setEditFormError(null);
  };

  // --- Achievement Assignment Handlers (New) ---
  const handleAssignAchievements = async () => {
      if (!profileUser || !isAdmin) return; // Only admin can assign

      console.log('ProfilePage: Opening achievement assignment modal.'); // Added log
      setIsAssigningAchievements(true);
      setEditFormError(null); // Reuse editFormError state for simplicity in modals

      try {
          // Fetch all available achievements
          // Use getAllAchievements function from service
          const allAchievements = await getAllAchievements();
          setAvailableAchievements(allAchievements);

          // Initialize selected achievements with the ones the user already has
          // We need the IDs of the user_achievements records to potentially delete them,
          // or just the achievement_id to manage assignment status.
          // Let's manage assignment status by achievement_id for simplicity in the modal UI.
          // The actual update will involve creating/deleting user_achievements records.
          const currentUserAchievementIds = achievements.map(ua => ua.achievement_id);
          setSelectedAchievementIdsToAssign(currentUserAchievementIds);


      } catch (err) {
          console.error('Error loading achievements for assignment:', err);
          setEditFormError(err.message || 'Не удалось загрузить список достижений.');
          // Close modal on error? Or show error inside? Let's show inside.
      }
  };

  const handleToggleAchievementAssignment = (achievementId) => {
      setSelectedAchievementIdsToAssign(prev => {
          const isSelected = prev.includes(achievementId);
          if (isSelected) {
              return prev.filter(id => id !== achievementId);
          } else {
              return [...prev, achievementId];
          }
      });
  };

  const handleSaveAchievementAssignment = async () => {
      if (!profileUser || !isAdmin) return;

      setIsSubmittingEdit(true); // Reuse submitting state
      setEditFormError(null);

      try {
          // Logic to update user_achievements collection
          // Compare userAchievementIds (current) with selectedAchievementIdsToAssign (desired)
          const currentIds = new Set(userAchievementIds);
          const desiredIds = new Set(selectedAchievementIdsToAssign);

          const idsToAdd = selectedAchievementIdsToAssign.filter(id => !currentIds.has(id));
          const idsToRemove = userAchievementIds.filter(id => !desiredIds.has(id));

          // Add new user_achievements records
          for (const achievementId of idsToAdd) {
              // Use awardAchievement function from service
              await awardAchievement(profileUser.id, achievementId, currentUser.id); // Pass current user as awarded_by
          }

          // Remove user_achievements records
          // Need to find the user_achievements record IDs for the achievements to remove
          const userAchievementsToRemove = achievements.filter(ua => idsToRemove.includes(ua.achievement_id));
          for (const ua of userAchievementsToRemove) {
              // Use pb instance imported directly
              await pb.collection('user_achievements').delete(ua.id);
          }

          console.log('Achievement assignment updated successfully.');
          setIsAssigningAchievements(false);
          loadProfileData(); // Refresh profile data to show updated achievements

      } catch (err) {
          console.error('Error saving achievement assignment:', err);
          const pbErrorData = err.response?.data?.data;
          let errorMessage = err.message || 'Произошла ошибка при сохранении достижений.';

          if (pbErrorData) {
              errorMessage = Object.entries(pbErrorData)
                  .map(([field, errorInfo]) => `${field}: ${errorInfo.message}`)
                  .join(', ');
          }
          setEditFormError(errorMessage);
      } finally {
          setIsSubmittingEdit(false);
      }
  };

  const handleCancelAchievementAssignment = () => {
      setIsAssigningAchievements(false);
      setEditFormError(null);
  };


  if (loading || authLoading || !authInitialized) { // Show loading if auth is still initializing/loading
    console.log('ProfilePage: Showing initial loading state. Loading:', loading, 'AuthLoading:', authLoading, 'AuthInitialized:', authInitialized);
    return (
      <div className="min-h-screen bg-campfire-dark pt-20 flex justify-center items-center">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-campfire-amber"></div>
      </div>
    );
  }

  if (error) {
    console.error('ProfilePage: Showing error state:', error);
    return (
      <div className="min-h-screen bg-campfire-dark pt-20 flex justify-center items-center">
        <div className="bg-status-error/20 text-status-error p-4 rounded-lg text-center">
          {error}
        </div>
      </div>
    );
  }

  if (!profileUser) {
     console.log('ProfilePage: Showing user not found state.');
    return (
      <div className="min-h-screen bg-campfire-dark pt-20 flex justify-center items-center">
        <div className="text-campfire-ash text-lg">Профиль пользователя не найден.</div>
      </div>
    );
  }

  const currentLevel = profileUser.level || 1;
  const currentXP = profileUser.xp || 0;
  const xpForCurrentLevel = getXpForCurrentLevel(currentLevel);
  const xpForNextLevel = getXpForNextLevel(currentLevel);
  const xpProgress = xpForNextLevel > xpForCurrentLevel ?
                     ((currentXP - xpForCurrentLevel) / (xpForNextLevel - xpForCurrentLevel)) * 100
                     : 100;

  const tabs = [
    { id: 'reviews', label: 'Рецензии' },
    { id: 'ratings', label: 'Оценки' },
    { id: 'lists', label: 'Списки' }
  ];

  return (
    <div className="min-h-screen bg-campfire-dark pt-0">
      {/* Banner Section */}
      <div
        className="relative h-64 bg-cover bg-center"
        style={{ backgroundImage: `url(${getFileUrl(profileUser, 'banner_picture') || 'https://images.pexels.com/photos/1103970/pexels-photo-1103970.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=1'})` }}
      >
        <div className="absolute inset-0 bg-gradient-to-t from-campfire-dark to-transparent opacity-90"></div>
        <div className="container-custom relative z-10 flex items-end h-full pb-8">
          <div className="flex items-center w-full">
            <img
              src={getFileUrl(profileUser, 'profile_picture') || 'https://images.pexels.com/photos/1704488/pexels-photo-1704488.jpeg?auto=compress&cs=tinysrgb&w=1260&h=750&dpr=1'}
              alt={profileUser.username}
              className="w-24 h-24 md:w-32 md:h-32 rounded-full border-4 border-campfire-dark shadow-xl object-cover"
            />
            <div className="ml-6 flex-grow">
              <h1 className="text-3xl md:text-4xl font-bold text-campfire-light mb-2">
                {profileUser.username}
              </h1>
              {/* User Stats */}
              <div className="flex items-center text-campfire-ash text-sm md:text-base">
                 <span className="mr-4">Уровень: <b className="text-campfire-amber">{profileUser.level || 1}</b></span>
                 <span className="mr-4">Рецензий: <b className="text-campfire-amber">{profileUser.review_count || 0}</b></span>
                 <span>Средняя оценка: <b className="text-campfire-amber">{profileUser.average_rating !== null && profileUser.average_rating !== undefined ? profileUser.average_rating.toFixed(1) : 'N/A'}</b></span>
              </div>
               {/* XP Progress Bar */}
               <div className="w-full bg-campfire-ash/30 rounded-full h-2.5 mt-2">
                   <div
                       className="bg-campfire-amber h-2.5 rounded-full transition-all duration-500 ease-out"
                       style={{ width: `${xpProgress}%` }}
                   ></div>
               </div>
               <p className="text-campfire-ash text-xs mt-1">
                   XP: {profileUser.xp || 0} / {xpForNextLevel} (до Уровня {currentLevel + 1})
               </p>
            </div>
          </div>
        </div>
      </div>

      <div className="container-custom py-12">
        {/* Description */}
        <div className="mb-12">
          <h2 className="text-2xl font-bold text-campfire-light mb-4">О себе</h2>
          <p className="text-campfire-ash leading-relaxed">
            {profileUser.description || 'Пользователь пока ничего не рассказал о себе.'}
          </p>
        </div>

        {/* Showcase Section */}
        <div className="mb-12">
            <div className="flex justify-between items-center mb-6 border-b border-campfire-ash/20 pb-4">
                <h2 className="text-2xl font-bold text-campfire-light">Витрина рецензий</h2>
                {isOwnProfile && (
                    <button
                        onClick={handleManageShowcase}
                        className="btn-secondary flex items-center space-x-2"
                    >
                        <FaEdit size={18} />
                        <span>Управлять витриной</span>
                    </button>
                )}
            </div>
            {profileUser.expand?.showcase && profileUser.expand.showcase.length > 0 ? (
                <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
                    {profileUser.expand.showcase.map(review => (
                        <ReviewItem
                            key={review.id}
                            review={review}
                            media={review.expand?.media_id}
                            season={review.expand?.season_id}
                            reviewCharacteristics={review.expand?.media_id?.characteristics || {}}
                            isProfilePage={true}
                        />
                    ))}
                </div>
            ) : (
                <div className="text-center py-8 text-campfire-light">
                    {isOwnProfile ? (
                        <>
                            Ваша витрина пуста. <button onClick={handleManageShowcase} className="text-campfire-amber hover:underline">Добавьте</button> сюда свои лучшие рецензии!
                        </>
                    ) : (
                        'У пользователя пока нет рецензий на витрине.'
                    )}
                </div>
            )}
        </div>


        {/* Achievements Section */}
        <div className="mb-12">
          <div className="flex justify-between items-center mb-6 border-b border-campfire-ash/20 pb-4">
            <h2 className="text-2xl font-bold text-campfire-light">Достижения</h2>
             {/* Assign Achievements Button (only for admins, visible on any profile) */}
             {isAdmin && ( // Use isAdmin check
                 <button
                     onClick={handleAssignAchievements} // New handler
                     className="btn-secondary flex items-center space-x-2"
                 >
                     <FaAward size={18} /> {/* Changed icon */}
                     <span>Назначить достижения</span> {/* Changed text */}
                 </button>
             )}
          </div>
          {achievements.length > 0 ? (
            <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-6">
              {achievements.map(ua => (
                <div key={ua.id} className="bg-campfire-charcoal rounded-lg shadow-md p-4 flex items-center space-x-4 border border-campfire-amber/30">
                  {ua.expand?.achievement_id ? (
                    <>
                      <div className="flex-shrink-0 text-campfire-amber">
                          <FaTrophy size={32} />
                      </div>
                      <div>
                        <h3 className="text-lg font-semibold text-campfire-light">{ua.expand.achievement_id.name}</h3>
                        <p className="text-campfire-ash text-sm">{ua.expand.achievement_id.description}</p>
                         {ua.expand.achievement_id.xp_reward > 0 && (
                            <p className="text-campfire-light text-xs mt-1 flex items-center">
                                <FaFire className="mr-1 text-campfire-amber" /> +{ua.expand.achievement_id.xp_reward} XP
                            </p>
                         )}
                      </div>
                    </>
                  ) : (
                    <p className="text-campfire-ash">Достижение (ID: {ua.achievement_id})</p>
                  )}
                </div>
              ))}
            </div>
          ) : (
            <div className="text-center py-8 text-campfire-light">
              У пользователя пока нет достижений.
            </div>
          )}
        </div>

        {/* All Reviews Section - Render as smaller cards */}
        <div className="mb-12">
          <h2 className="text-2xl font-bold text-campfire-light mb-6 border-b border-campfire-ash/20 pb-4">Все рецензии</h2>
          {reviews.length > 0 ? (
            <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-3 gap-6"> {/* Use grid for smaller cards */}
                {reviews.map(review => (
                     <ReviewItem
                        key={review.id}
                        review={review}
                        media={review.expand?.media_id}
                        season={review.expand?.season_id}
                        reviewCharacteristics={review.expand?.media_id?.characteristics || {}}
                        isProfilePage={true} // Indicate it's on the profile page
                        isSmallCard={true} // Indicate it should render as a small card
                    />
                ))}
            </div>
          ) : (
            <div className="text-center py-8 text-campfire-light">
              У пользователя пока нет рецензий.
            </div>
          )}
        </div>
      </div>

      {/* Profile Edit Modal */}
      {profileUser && (
          <Modal
              isOpen={isEditingProfile}
              onClose={handleEditFormCancel}
              title={`Редактировать профиль: ${profileUser.username}`}
              size="lg"
          >
              <form onSubmit={handleEditFormSubmit} className="space-y-6">
                  {editFormError && (
                      <div className="bg-red-500/10 border border-red-500/20 text-red-500 p-4 rounded-lg">
                          Ошибка: {editFormError}
                      </div>
                  )}

                  {/* Description */}
                  <div>
                      <label htmlFor="description" className="block mb-2 text-campfire-light text-sm font-medium">
                          О себе (опционально)
                      </label>
                      <textarea
                          id="description"
                          name="description"
                          rows="4"
                          value={editFormData.description}
                          onChange={handleEditFormChange}
                          className="w-full p-3 bg-campfire-dark border border-campfire-ash/30 rounded-md text-campfire-light focus:ring-2 focus:ring-campfire-amber focus:border-transparent transition-colors"
                      />
                  </div>

                  {/* Profile Picture */}
                  <div>
                      <label htmlFor="profile_picture" className="block mb-2 text-campfire-light text-sm font-medium">
                          Фото профиля (опционально)
                      </label>
                      {profileUser.profile_picture && !deleteProfilePicture && (
                          <div className="mb-4">
                              <p className="text-sm text-campfire-ash mb-2">Текущее фото:</p>
                              <img src={getFileUrl(profileUser, 'profile_picture')} alt="Current Profile" className="w-20 h-20 rounded-full mb-2 object-cover" />
                              <button
                                  type="button"
                                  onClick={() => handleRemoveExistingPicture('profile_picture')}
                                  className="text-red-500 hover:underline text-sm"
                              >
                                  Удалить текущее фото
                              </button>
                          </div>
                      )}
                      <input
                          type="file"
                          id="profile_picture"
                          name="profile_picture"
                          onChange={handleEditFileChange}
                          className="w-full text-campfire-light text-sm
                             file:mr-4 file:py-2 file:px-4
                             file:rounded-md file:border-0
                             file:text-sm file:font-semibold
                             file:bg-campfire-amber file:text-campfire-dark
                             hover:file:bg-campfire-amber/80 cursor-pointer"
                      />
                  </div>

                  {/* Banner Picture */}
                  <div>
                      <label htmlFor="banner_picture" className="block mb-2 text-campfire-light text-sm font-medium">
                          Баннер профиля (опционально)
                      </label>
                      {profileUser.banner_picture && !deleteBannerPicture && (
                          <div className="mb-4">
                              <p className="text-sm text-campfire-ash mb-2">Текущий баннер:</p>
                              <img src={getFileUrl(profileUser, 'banner_picture')} alt="Current Banner" className="w-full h-32 object-cover rounded-md mb-2" />
                              <button
                                  type="button"
                                  onClick={() => handleRemoveExistingPicture('banner_picture')}
                                  className="text-red-500 hover:underline text-sm"
                               >
                                  Удалить текущий баннер
                              </button>
                          </div>
                      )}
                      <input
                          type="file"
                          id="banner_picture"
                          name="banner_picture"
                          onChange={handleEditFileChange}
                          className="w-full text-campfire-light text-sm
                             file:mr-4 file:py-2 file:px-4
                             file:rounded-md file:border-0
                             file:text-sm file:font-semibold
                             file:bg-campfire-amber file:text-campfire-dark
                             hover:file:bg-campfire-amber/80 cursor-pointer"
                    />
                  </div>


                  {/* Form Actions */}
                  <div className="flex justify-end space-x-4 mt-6">
                      <button
                          type="button"
                          onClick={handleEditFormCancel}
                          className="btn-secondary"
                          disabled={isSubmittingEdit}
                      >
                          Отмена
                      </button>
                      <button
                          type="submit"
                          className="btn-primary disabled:opacity-50 disabled:cursor-not-allowed"
                          disabled={isSubmittingEdit}
                      >
                          {isSubmittingEdit ? 'Сохранение...' : 'Сохранить изменения'}
                      </button>
                  </div>
              </form>
          </Modal>
      )}

      {/* Showcase Management Modal */}
      {profileUser && isOwnProfile && (
          <Modal
              isOpen={isManagingShowcase}
              onClose={handleCancelShowcase}
              title={`Управление витриной (${selectedShowcaseReviewIds.length}/3)`}
              size="lg"
          >
              <div className="space-y-4">
                  {editFormError && (
                      <div className="bg-red-500/10 border border-red-500/20 text-red-500 p-4 rounded-lg">
                          Ошибка: {editFormError}
                      </div>
                  )}
                  <p className="text-campfire-ash text-sm">Выберите до 3 рецензий, которые будут отображаться на вашей витрине.</p>
                  {reviews.length > 0 ? (
                      <ul className="space-y-3 max-h-96 overflow-y-auto pr-2 custom-scrollbar">
                          {reviews.map(review => {
                              const reviewMedia = review.expand?.media_id;
                              const reviewSeason = review.expand?.season_id;
                              const isSelected = selectedShowcaseReviewIds.includes(review.id);

                              const reviewTitle = reviewMedia
                                  ? `${reviewMedia.title}${reviewSeason ? ` - Сезон ${reviewSeason.season_number}${reviewSeason.title ? `: ${reviewSeason.title}` : ''}` : ''}`
                                  : 'Неизвестное произведение';


                              return (
                                  <li
                                      key={review.id}
                                      className={`p-3 rounded-md border cursor-pointer flex items-center justify-between transition-colors duration-200
                                          ${isSelected
                                              ? 'bg-campfire-amber/20 border-campfire-amber text-campfire-light'
                                              : 'bg-campfire-dark border-campfire-ash/30 text-campfire-ash hover:bg-campfire-ash/10'
                                          }`}
                                      onClick={() => handleToggleShowcaseReview(review.id)}
                                  >
                                      <div className="flex-grow mr-4">
                                          <p className="font-semibold text-sm">{reviewTitle}</p>
                                          <p className="text-xs mt-1 flex items-center">
                                             Оценка: <span className="flex items-center text-campfire-amber ml-1 font-bold">
                                                <FaFire className="mr-1 text-xs" />
                                                {/* Corrected access to overall_rating */}
                                                {review.overall_rating !== null && review.overall_rating !== undefined ? review.overall_rating.toFixed(1) : 'N/A'} / 10
                                             </span>
                                          </p>
                                      </div>
                                      {isSelected ? (
                                          <FaCheckCircle size={20} className="text-campfire-amber" />
                                      ) : (
                                          <FaRegCircle size={20} className="text-campfire-ash" />
                                      )}
                                  </li>
                              );
                          })}
                      </ul>
                  ) : (
                      <div className="text-center py-4 text-campfire-ash">
                          У вас пока нет рецензий для добавления на витрину.
                      </div>
                  )}

                  {/* Form Actions */}
                  <div className="flex justify-end space-x-4 mt-6">
                      <button
                          type="button"
                          onClick={handleCancelShowcase}
                          className="btn-secondary"
                          disabled={isSubmittingEdit}
                      >
                          Отмена
                      </button>
                      <button
                          type="button"
                          onClick={handleSaveShowcase}
                          className="btn-primary disabled:opacity-50 disabled:cursor-not-allowed"
                          disabled={isSubmittingEdit}
                      >
                          {isSubmittingEdit ? 'Сохранение...' : 'Сохранить витрину'}
                      </button>
                  </div>
              </div>
          </Modal>
      )}

      {/* Achievement Assignment Modal (New) */}
      {profileUser && isAdmin && ( // Only show if profileUser is loaded and current user is admin
          <Modal
              isOpen={isAssigningAchievements}
              onClose={handleCancelAchievementAssignment}
              title={`Назначить достижения для ${profileUser.username}`}
              size="lg"
          >
              <div className="space-y-4">
                  {editFormError && ( // Reuse error state
                      <div className="bg-red-500/10 border border-red-500/20 text-red-500 p-4 rounded-lg">
                          Ошибка: {editFormError}
                      </div>
                  )}
                  <p className="text-campfire-ash text-sm">Выберите достижения, которые нужно назначить или снять с пользователя.</p>
                  {availableAchievements.length > 0 ? (
                      <ul className="space-y-3 max-h-96 overflow-y-auto pr-2 custom-scrollbar">
                          {availableAchievements.map(achievement => {
                              const isSelected = selectedAchievementIdsToAssign.includes(achievement.id);

                              return (
                                  <li
                                      key={achievement.id}
                                      className={`p-3 rounded-md border cursor-pointer flex items-center justify-between transition-colors duration-200
                                          ${isSelected
                                              ? 'bg-campfire-amber/20 border-campfire-amber text-campfire-light'
                                              : 'bg-campfire-dark border-campfire-ash/30 text-campfire-ash hover:bg-campfire-ash/10'
                                          }`}
                                      onClick={() => handleToggleAchievementAssignment(achievement.id)}
                                  >
                                      <div className="flex-grow mr-4">
                                          <p className="font-semibold text-sm">{achievement.name}</p>
                                          <p className="text-xs text-campfire-ash mt-1">{achievement.description}</p>
                                           {achievement.xp_reward > 0 && (
                                              <p className="text-campfire-light text-xs mt-1 flex items-center">
                                                  <FaFire className="mr-1 text-campfire-amber" /> +{achievement.xp_reward} XP
                                              </p>
                                           )}
                                      </div>
                                      {isSelected ? (
                                          <FaCheckCircle size={20} className="text-campfire-amber" />
                                      ) : (
                                          <FaRegCircle size={20} className="text-campfire-ash" />
                                      )}
                                  </li>
                              );
                          })}
                      </ul>
                  ) : (
                      <div className="text-center py-4 text-campfire-ash">
                          Нет доступных достижений.
                      </div>
                  )}

                  {/* Form Actions */}
                  <div className="flex justify-end space-x-4 mt-6">
                      <button
                          type="button"
                          onClick={handleCancelAchievementAssignment}
                          className="btn-secondary"
                          disabled={isSubmittingEdit}
                      >
                          Отмена
                      </button>
                      <button
                          type="button"
                          onClick={handleSaveAchievementAssignment}
                          className="btn-primary disabled:opacity-50 disabled:cursor-not-allowed"
                          disabled={isSubmittingEdit}
                      >
                          {isSubmittingEdit ? 'Сохранение...' : 'Сохранить изменения'}
                      </button>
                  </div>
              </div>
          </Modal>
      )}


    </div>
  );
};

export default ProfilePage;
