import React, { useState, useEffect } from 'react';
import { useAuth } from '../contexts/AuthContext';
import { Navigate, useNavigate } from 'react-router-dom';
import { updateUserProfile, uploadFile, deleteFile, getFileUrl } from '../services/pocketbaseService'; // Use PocketBase service
import { toast } from 'react-toastify';
import { FaSpinner } from 'react-icons/fa';

const ProfileSettingsPage = () => {
  const { user, userProfile, isInitialized, loading: authLoading, error: authError, refreshUserProfile } = useAuth(); // user and userProfile are the same PocketBase record
  const navigate = useNavigate();

  const [formData, setFormData] = useState({
    username: '',
    description: '',
    profile_picture_file: undefined, // Use undefined initially to distinguish from null (cleared)
    banner_picture_file: undefined, // Use undefined initially to distinguish from null (cleared)
  });

  const [previewAvatar, setPreviewAvatar] = useState(null); // URL for avatar preview
  const [previewBanner, setPreviewBanner] = useState(null); // URL for banner preview
  const [isSaving, setIsSaving] = useState(false);
  const [saveError, setSaveError] = useState(null);

  // Store initial data for comparison
  const [initialData, setInitialData] = useState(null);
  // Store initial file names for comparison (PocketBase stores filenames)
  const [initialFiles, setInitialFiles] = useState({
      profile_picture: null,
      banner_picture: null, // Corrected key
  });


  // Effect to populate form when userProfile is loaded
  useEffect(() => {
    if (userProfile) {
      const dataToPopulate = {
        username: userProfile.username || '',
        description: userProfile.description || '',
        profile_picture_file: undefined, // Reset file inputs to undefined (not touched)
        banner_picture_file: undefined, // Reset file inputs to undefined (not touched)
      };
      setFormData(dataToPopulate);
      // Store initial data for comparison
      setInitialData(dataToPopulate);

      // Store initial file names
      setInitialFiles({
          profile_picture: userProfile.profile_picture || null,
          banner_picture: userProfile.banner_picture || null, // Corrected key
      });


      // Use the actual URLs from userProfile for initial previews
      // PocketBase file fields store filenames, use getFileUrl to get the actual URL
      setPreviewAvatar(getFileUrl(userProfile, 'profile_picture') || null);
      setPreviewBanner(getFileUrl(userProfile, 'banner_picture') || null); // Corrected field name
    }
  }, [userProfile]);

  // Wait for auth to initialize before deciding
  if (!isInitialized || authLoading) {
    return (
      <div className="min-h-screen flex items-center justify-center bg-campfire-dark pt-20">
        <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-campfire-amber"></div>
      </div>
    );
  }

  // If user is not logged in, redirect to login page
  if (!user) {
    return <Navigate to="/auth" replace />;
  }

  // If user is logged in but profile is not loaded yet (and not saving), show loading
  // This handles the case where user is logged in but userProfile is still null initially
  // In PocketBase, user and userProfile are the same record from authStore.model,
  // so if user exists, userProfile should also exist unless there's an init issue.
  // Still good to keep this check for robustness.
  if (!userProfile && !isSaving) {
     return (
        <div className="min-h-screen flex items-center justify-center bg-campfire-dark pt-20">
           <div className="animate-spin rounded-full h-12 w-12 border-t-2 border-b-2 border-campfire-amber"></div>
        </div>
     );
  }


  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setFormData({ ...formData, [name]: value });
  };

  const handleFileChange = (e) => {
    const { name, files } = e.target;
    const file = files[0];

    // Determine which file input changed based on the 'name' attribute
    const isAvatar = name === 'profile_picture';
    const isBanner = name === 'banner_picture'; // Corrected name check

    if (file) {
      // Update the correct file state variable
      if (isAvatar) {
        setFormData(prev => ({ ...prev, profile_picture_file: file }));
        // Create a preview URL
        const reader = new FileReader();
        reader.onloadend = () => setPreviewAvatar(reader.result);
        reader.readAsDataURL(file);
      } else if (isBanner) { // Corrected check
        setFormData(prev => ({ ...prev, banner_picture_file: file })); // Corrected state key
        // Create a preview URL
        const reader = new FileReader();
        reader.onloadend = () => setPreviewBanner(reader.result);
        reader.readAsDataURL(file);
      }
    } else {
       // If file input is cleared (user cancels file selection or clicks clear)
       if (isAvatar) {
          setFormData(prev => ({ ...prev, profile_picture_file: null })); // Set to null to indicate clearing
          // Revert preview to the original URL from userProfile if it exists
          setPreviewAvatar(getFileUrl(userProfile, 'profile_picture') || null);
       } else if (isBanner) { // Corrected check
          setFormData(prev => ({ ...prev, banner_picture_file: null })); // Set to null to indicate clearing
          // Revert preview to the original URL from userProfile if it exists
          setPreviewBanner(getFileUrl(userProfile, 'banner_picture') || null); // Corrected field name
       }
    }
  };

  const handleClearFile = async (type) => {
     if (!user || !userProfile) return;

     const fileStateKey = type === 'avatar' ? 'profile_picture_file' : 'banner_picture_file'; // Corrected state key for banner
     const previewSetter = type === 'avatar' ? setPreviewAvatar : setPreviewBanner;

     // Clear the file input state by setting it to null
     setFormData(prev => ({ ...prev, [fileStateKey]: null }));
     // Clear the preview immediately
     previewSetter(null);

     console.log(`Marked ${type} file for clearing.`);
  };


  const handleSubmit = async (e) => {
    e.preventDefault();
    if (!user || !userProfile || !initialData || !initialFiles) return; // Ensure initialData and initialFiles are available

    setIsSaving(true);
    setSaveError(null);

    const formDataToSubmit = new FormData();
    let changesMade = false;

    // Handle Text Field Changes
    if (formData.username !== initialData.username) {
        formDataToSubmit.append('username', formData.username);
        changesMade = true;
        console.log('Username changed:', formData.username);
    }
    if (formData.description !== initialData.description) {
        formDataToSubmit.append('description', formData.description);
        changesMade = true;
        console.log('Description changed:', formData.description);
    }

    // Handle Avatar File Change/Clear
    const newAvatarFile = formData.profile_picture_file; // Can be File, null (cleared), or undefined (not touched)
    const initialAvatarFileName = initialFiles.profile_picture; // Can be string (filename) or null

    // Check if the avatar file input was touched (either a new file selected or cleared)
    if (newAvatarFile !== undefined) {
        if (newAvatarFile instanceof File) {
            // New avatar file selected
            console.log('New avatar file selected. Adding to FormData.');
            formDataToSubmit.append('profile_picture', newAvatarFile);
            changesMade = true;
        } else if (newAvatarFile === null && initialAvatarFileName) {
            // Avatar input was cleared AND there was an existing avatar - mark for deletion
            console.log('Avatar cleared. Marking profile_picture for deletion.');
            formDataToSubmit.append('profile_picture', null); // Set field to null to delete file
            changesMade = true;
        }
        // If newAvatarFile is null and initialAvatarFileName is null, do nothing (already no file).
    }
    // If newAvatarFile is undefined, the input wasn't touched, do nothing (keep existing file if any).


    // Handle Banner File Change/Clear
    const newBannerFile = formData.banner_picture_file; // Can be File, null (cleared), or undefined (not touched)
    const initialBannerFileName = initialFiles.banner_picture; // Can be string (filename) or null

    // Check if the banner file input was touched (either a new file selected or cleared)
    if (newBannerFile !== undefined) {
        if (newBannerFile instanceof File) {
            // New banner file selected
            console.log('New banner file selected. Adding to FormData.');
            formDataToSubmit.append('banner_picture', newBannerFile);
            changesMade = true;
        } else if (newBannerFile === null && initialBannerFileName) {
            // Banner input was cleared AND there was an existing banner - mark for deletion
            console.log('Banner cleared. Marking banner_picture for deletion.');
            formDataToSubmit.append('banner_picture', null); // Set field to null to delete file
            changesMade = true;
        }
        // If newBannerFile is null and initialBannerFileName is null, do nothing (already no file).
    }
    // If newBannerFile is undefined, the input wasn't touched, do nothing (keep existing file if any).


    // Check if any changes were made
    if (!changesMade) {
        console.log('No changes detected, cancelling save.');
        toast.info('Нет изменений для сохранения.');
        setIsSaving(false);
        return; // Stop the submission process
    }

    // Log FormData contents before sending (for debugging)
    console.log('Attempting to update profile with FormData:');
    for (let pair of formDataToSubmit.entries()) {
        console.log(pair[0]+ ': ' + pair[1]);
    }


    try {
      // PocketBase update method correctly handles FormData with partial updates
      // Only fields present in FormData will be updated.
      await updateUserProfile(user.id, formDataToSubmit); // Pass the single FormData object
      console.log('Profile update successful.');

      // Refresh the user record in context to get the latest data and file URLs
      await refreshUserProfile();

      toast.success('Профиль успешно обновлен!');
      navigate(`/profile/${user.username}`);

    } catch (error) {
      console.error('Failed to save profile:', error);
      if (error.response && error.response.data) {
         console.error('PocketBase: Response data:', error.response.data);
         // Check for specific PocketBase validation errors
         if (error.response.data.username && error.response.data.username.code === 'validation_not_unique') {
            setSaveError('Имя пользователя уже занято.');
            toast.error('Имя пользователя уже занято.');
         } else {
            // Generic error message from PocketBase response
            const errorMessages = Object.values(error.response.data).map(err => err.message).join(', ');
            setSaveError(`Ошибка сохранения: ${errorMessages || error.message}`);
            toast.error(`Ошибка сохранения профиля: ${errorMessages || error.message}`);
         }
      } else {
         // General error message
         setSaveError(error.message || 'Произошла ошибка при сохранении.');
         toast.error(`Ошибка сохранения профиля: ${error.message || 'Произошла ошибка'}`);
      }
    } finally {
      setIsSaving(false);
    }
  };

  // Render the settings page content for the logged-in user
  return (
    <div className="min-h-screen bg-campfire-dark pt-20">
      <div className="container-custom py-12">
        <div className="bg-campfire-charcoal rounded-lg shadow-lg border border-campfire-ash/20 p-8">
          <h1 className="text-2xl font-bold text-campfire-light mb-6">
            Настройки профиля
          </h1>

          {saveError && (
            <div className="bg-red-800 text-white p-3 rounded mb-4">
              {saveError}
            </div>
          )}

          {userProfile && (
            <form onSubmit={handleSubmit} className="space-y-6">
              {/* Avatar Upload */}
              <div>
                <label htmlFor="profile_picture" className="block text-sm font-medium text-campfire-ash mb-2">
                  Аватар
                </label>
                <div className="flex items-center space-x-4">
                  <div className="flex-shrink-0">
                    <img
                      className="h-20 w-20 rounded-full object-cover border border-campfire-ash/30"
                      // Use previewAvatar (FileReader URL) if a new file is selected,
                      // otherwise use the URL from the userProfile (generated by getFileUrl)
                      src={previewAvatar || getFileUrl(userProfile, 'profile_picture') || 'https://via.placeholder.com/150/333333/FFFFFF?text=No+Avatar'}
                      alt="Аватар пользователя"
                    />
                  </div>
                  <div>
                    <input
                      type="file"
                      id="profile_picture"
                      name="profile_picture" // Use name matching handleFileChange logic
                      accept="image/*"
                      onChange={handleFileChange}
                      className="block w-full text-sm text-campfire-ash
                        file:mr-4 file:py-2 file:px-4
                        file:rounded-full file:border-0
                        file:text-sm file:font-semibold
                        file:bg-campfire-amber file:text-campfire-dark
                        hover:file:bg-campfire-amber/80 cursor-pointer"
                    />
                     {(previewAvatar || getFileUrl(userProfile, 'profile_picture')) && ( // Show clear button if there's a preview or existing picture
                        <button
                           type="button"
                           onClick={() => handleClearFile('avatar')}
                           className="mt-2 text-sm text-red-400 hover:text-red-500"
                        >
                           Удалить аватар
                        </button>
                     )}
                  </div>
                </div>
              </div>

              {/* Banner Upload */}
              <div>
                <label htmlFor="banner_picture" className="block text-sm font-medium text-campfire-ash mb-2"> {/* Corrected htmlFor and label text */}
                  Баннер
                </label>
                <div className="relative w-full h-40 rounded-lg overflow-hidden border border-campfire-ash/30 bg-campfire-dark">
                   {/* Use previewBanner or getFileUrl for banner */}
                   {(previewBanner || getFileUrl(userProfile, 'banner_picture')) ? (
                      <img
                         className="w-full h-full object-cover"
                         src={previewBanner || getFileUrl(userProfile, 'banner_picture')} // Corrected field name
                         alt="Баннер пользователя"
                      />
                   ) : (
                      <div className="w-full h-full flex items-center justify-center text-campfire-ash/50">
                         Нет баннера
                      </div>
                   )}
                   <input
                      type="file"
                      id="banner_picture" // Corrected id
                      name="banner_picture" // Corrected name matching handleFileChange logic
                      accept="image/*"
                      onChange={handleFileChange}
                      className="absolute inset-0 w-full h-full opacity-0 cursor-pointer"
                   />
                </div>
                 {(previewBanner || getFileUrl(userProfile, 'banner_picture')) && ( // Show clear button if there's a preview or existing banner (Corrected field name)
                    <button
                       type="button"
                       onClick={() => handleClearFile('banner')}
                       className="mt-2 text-sm text-red-400 hover:text-red-500"
                    >
                       Удалить баннер
                    </button>
                 )}
              </div>


              {/* Username Input */}
              <div>
                <label htmlFor="username" className="block text-sm font-medium text-campfire-ash mb-2">
                  Имя пользователя
                </label>
                <input
                  type="text"
                  id="username"
                  name="username"
                  value={formData.username}
                  onChange={handleInputChange}
                  className="w-full px-3 py-2 bg-campfire-dark text-campfire-light border border-campfire-ash/30 rounded-md focus:outline-none focus:ring-campfire-amber focus:border-campfire-amber"
                  required
                />
              </div>

              {/* Description (Bio) Textarea */}
              <div>
                <label htmlFor="description" className="block text-sm font-medium text-campfire-ash mb-2">
                  О себе (Биография)
                </label>
                <textarea
                  id="description"
                  name="description"
                  value={formData.description}
                  onChange={handleInputChange}
                  rows="4"
                  className="w-full px-3 py-2 bg-campfire-dark text-campfire-light border border-campfire-ash/30 rounded-md focus:outline-none focus:ring-campfire-amber focus:border-campfire-amber"
                ></textarea>
              </div>

              {/* Stats (Placeholder) */}
              <div>
                 <h3 className="text-lg font-semibold text-campfire-light mb-4">Статистика</h3>
                 <div className="grid grid-cols-1 md:grid-cols-2 gap-4 text-campfire-ash">
                    <div className="bg-campfire-dark p-4 rounded-md border border-campfire-ash/30">
                       <p className="text-sm">Всего обзоров:</p>
                       <p className="text-xl font-bold text-campfire-light">{userProfile.review_count || 0}</p>
                    </div>
                    <div className="bg-campfire-dark p-4 rounded-md border border-campfire-ash/30">
                       <p className="text-sm">Средняя оценка:</p>
                       <p className="text-xl font-bold text-campfire-light">{userProfile.average_rating ? userProfile.average_rating.toFixed(1) : 'N/A'}</p>
                    </div>
                    {/* Add more stats here if available in userProfile */}
                 </div>
              </div>


              {/* Save Button */}
              <div>
                <button
                  type="submit"
                  className="w-full bg-campfire-amber text-campfire-dark font-bold py-2 px-4 rounded-md hover:bg-campfire-amber/80 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-campfire-amber focus:ring-opacity-50 disabled:opacity-50 disabled:cursor-not-allowed"
                  disabled={isSaving}
                >
                  {isSaving ? (
                    <span className="flex items-center">
                      <FaSpinner className="animate-spin mr-2" />
                      Сохранение...
                    </span>
                  ) : (
                    'Сохранить изменения'
                  )}
                </button>
              </div>
            </form>
          )}
        </div>
      </div>
    </div>
  );
};

export default ProfileSettingsPage;
