import PocketBase from 'pocketbase';
import { v4 as uuidv4 } from 'uuid'; // Import uuid

const pbUrl = import.meta.env.VITE_POCKETBASE_URL;

if (!pbUrl) {
  console.error('Missing VITE_POCKETBASE_URL environment variable');
  throw new Error('Missing VITE_POCKETBASE_URL environment variable');
}

const pb = new PocketBase(pbUrl);

// Disable auto-cancellation to prevent issues with concurrent requests
pb.autoCancellation(false);
console.log('[PocketBase] Инициализирован с URL:', pbUrl);

// --- REMOVED: Explicit cookie loading and saving ---
// pb.authStore.loadFromCookie(document.cookie);
// pb.authStore.onChange(() => {
//     document.cookie = pb.authStore.exportToCookie({ httpOnly: false });
// });
// --- END REMOVED ---

console.log('PocketBase client initialized with URL:', pbUrl);

// --- Media Types Definition ---
// Define the available media types and their display labels
export const mediaTypes = {
  movie: { label: 'Фильм' },
  tv: { label: 'Сериал' },
  game: { label: 'Игра' },
  anime: { label: 'Аниме' },
  // Add other types here if needed
};


// --- XP and Level Calculation ---

// Simple function to calculate level based on XP
// This is a basic example, you might want a more complex formula or lookup table
export const calculateLevel = (xp) => {
    if (xp < 50) return 1;
    if (xp < 150) return 2;
    if (xp < 300) return 3;
    if (xp < 500) return 4;
    if (xp < 800) return 5;
    if (xp < 1200) return 6;
    if (xp < 1700) return 7;
    if (xp < 2300) return 8;
    if (xp < 3000) return 9;
    if (xp < 4000) return 10;
    // Add more levels as needed
    return 10 + Math.floor((xp - 4000) / 1000); // Example: +1 level every 1000 XP after level 10
};

// Function to get the XP required for the next level
export const getXpForNextLevel = (currentLevel) => {
    // This should correspond to the thresholds in calculateLevel
    // For level N, the next level is N+1. We need the minimum XP for level N+1.
    switch (currentLevel) {
        case 1: return 50;
        case 2: return 150;
        case 3: return 300;
        case 4: return 500;
        case 5: return 800;
        case 6: return 1200;
        case 7: return 1700;
        case 8: return 2300;
        case 9: return 3000;
        case 10: return 4000;
        default:
            // For levels > 10, each level requires 1000 XP more than the start of the previous level range
            // Level N (N > 10) starts at 4000 + (N - 10) * 1000
            return 4000 + (currentLevel - 10) * 1000;
    }
};

// Function to get the XP required for the current level (the starting point)
export const getXpForCurrentLevel = (currentLevel) => {
     if (currentLevel <= 1) return 0; // Level 1 starts at 0 XP
     // For levels > 1, the start XP is the XP needed for the current level
     return getXpForNextLevel(currentLevel - 1);
};


// --- Auth Functions ---

// PocketBase uses a single sign-up function for users
export const signUp = async (login, password, email = null) => {
  try {
    console.log('PocketBase: Начало регистрации:', { login, email });

    // Создаем FormData для загрузки дефолтного аватара
    const formData = new FormData();
    formData.append('login', login);
    formData.append('username', login); // Дублируем login в username
    formData.append('email', email || '');
    formData.append('password', password);
    formData.append('passwordConfirm', password);
    formData.append('emailVisibility', 'false');
    formData.append('role', 'user');
    formData.append('is_critic', 'false');
    formData.append('description', '');
    formData.append('review_count', '0');
    formData.append('average_rating', '0');
    formData.append('xp', '0');
    formData.append('level', '1');
    formData.append('showcase', '[]');

    // Создаем пользователя
    const record = await pb.collection('users').create(formData);
    console.log('PocketBase: Пользователь создан:', record);

    // Очищаем текущую сессию перед авторизацией
    pb.authStore.clear();

    // Auto-login after successful signup
    const authData = await pb.collection('users').authWithPassword(login, password);
    console.log('PocketBase: Автоматический вход после регистрации успешен:', authData);

    // Return the authenticated user and their record
    return { user: authData.record, profile: authData.record };

  } catch (error) {
    console.error('PocketBase: Ошибка при регистрации:', error);
    if (error.response && error.response.data) {
      console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

export const signIn = async (login, password) => {
  try {
    console.log('PocketBase: Попытка входа для', login);
    const authData = await pb.collection('users').authWithPassword(login, password);
    console.log('PocketBase: Вход успешен:', authData);
    return authData.record;
  } catch (error) {
    console.error('PocketBase: Ошибка входа:', error);
    if (error.response && error.response.data) {
      console.error('PocketBase: Response data:', error.response.data);
      if (error.response.data.message) {
        if (error.response.data.message.includes('Invalid login credentials')) {
          throw new Error('Неверный логин или пароль');
        }
        if (error.response.data.message.includes('Failed to authenticate')) {
          throw new Error('Неверный логин или пароль');
        }
        throw new Error(error.response.data.message);
      }
    }
    throw new Error('Произошла ошибка при входе. Пожалуйста, попробуйте позже.');
  }
};

export const signOut = async () => {
  try {
    console.log('PocketBase: Попытка выхода');
    pb.authStore.clear();
    console.log('PocketBase: Выход успешен');
  } catch (error) {
    console.error('PocketBase: Ошибка выхода:', error);
    throw error;
  }
};

export const getCurrentUser = () => {
  // PocketBase stores the authenticated user in authStore.model
  return pb.authStore.isValid ? pb.authStore.model : null;
};

// New function to request password reset
export const requestPasswordReset = async (email) => {
  try {
    console.log('PocketBase: Попытка запроса сброса пароля для', email);
    // PocketBase SDK function for password reset request
    await pb.collection('users').requestPasswordReset(email);
    console.log('PocketBase: Запрос на сброс пароля отправлен для', email);
    return true; // Indicate success
  } catch (error) {
    console.error('PocketBase: Ошибка при запроса сброса пароля:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};


// --- User Functions (PocketBase 'users' collection) ---
export const getUserProfile = async (userId) => {
  try {
    console.log('[PocketBase] Загрузка профиля:', userId);
    const record = await pb.collection('users').getOne(userId, {
      expand: 'showcase,showcase.media_id,showcase.season_id'
    });
    return record;
  } catch (error) {
    console.error('[PocketBase] Ошибка загрузки профиля:', error);
    throw error;
  }
};

// New function to get user profile by username
export const getUserProfileByUsername = async (username) => {
  try {
    console.log('[PocketBase] Поиск профиля по имени:', username);
    const userRecord = await pb.collection('users').getFirstListItem(`username="${username}"`, {
      expand: 'showcase,showcase.media_id,showcase.season_id'
    });
    return userRecord;
  } catch (error) {
    console.error('[PocketBase] Профиль не найден:', username);
    throw error;
  }
};


export const updateUserProfile = async (userId, profileData) => {
  try {
    console.log('PocketBase: Обновление профиля пользователя:', userId, 'с данными:', profileData);
    // PocketBase update requires the record ID
    // Note: This function is intended for updating non-file fields.
    // File uploads/deletions are handled by uploadFile/deleteFile.
    const record = await pb.collection('users').update(userId, profileData);
    console.log('PocketBase: Профиль пользователя обновлен успешно:', record);
    console.log('PocketBase: Обновленная профиль статистика:', { average_rating: record.average_rating, review_count: record.review_count, xp: record.xp, level: record.level }); // Log new fields
    return record;
  } catch (error) {
    console.error('PocketBase: Ошибка обновления профиля:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

// New function to update the user's showcase reviews
export const updateUserShowcase = async (userId, reviewIds) => {
    if (!userId) {
        console.warn('PocketBase: updateUserShowcase called with undefined userId');
        return null;
    }
    if (!Array.isArray(reviewIds) || reviewIds.length > 3) {
        console.error('PocketBase: updateUserShowcase called with invalid reviewIds array (must be array <= 3)');
        throw new Error('Invalid reviewIds array');
    }
    try {
        console.log('PocketBase: Обновление витрины пользователя:', userId, 'с рецензиями:', reviewIds);
        // Update the 'showcase' multiple relation field
        const updatedUser = await pb.collection('users').update(userId, {
            showcase: reviewIds // Pass the array of review IDs
        });
        console.log('PocketBase: Витрина пользователя обновлена успешно:', updatedUser);
        return updatedUser;
    } catch (error) {
        console.error('PocketBase: Ошибка обновления витрины пользователя:', error);
         if (error.response && error.response.data) {
            console.error('PocketBase: Response data:', error.response.data);
        }
        throw error;
    }
};

// New function to list users ranked by review count
export const listUsersRankedByReviews = async (limit = 20) => {
    console.log('PocketBase: Получение списка пользователей по количеству рецензий (лимит:', limit, ')');
    try {
        // Fetch users, sorted by review_count descending
        const records = await pb.collection('users').getList(1, limit, {
            sort: '-review_count',
            filter: 'review_count > 0', // Only include users with at least one review
            // You might want to select specific fields to reduce payload size
            // fields: 'id,username,profile_picture,review_count'
        });
        console.log('PocketBase: Получен список пользователей по рецензиям:', records.items);
        return records.items;
    } catch (error) {
        console.error('PocketBase: Ошибка получения списка пользователей по рецензиям:', error);
        throw error;
    }
};

// New function to list users ranked by level
export const listUsersRankedByLevel = async (limit = 20) => {
    console.log('PocketBase: Получение списка пользователей по уровню (лимит:', limit, ')');
    try {
        // Fetch users, sorted by level descending, then XP descending
        const records = await pb.collection('users').getList(1, limit, {
            sort: '-level,-xp', // Sort by level first, then XP
            filter: 'level > 1 || xp > 0', // Only include users above level 1 or with some XP
            // You might want to select specific fields to reduce payload size
            // fields: 'id,username,profile_picture,level,xp'
        });
        console.log('PocketBase: Получен список пользователей по уровню:', records.items);
        return records.items;
    } catch (error) {
        console.error('PocketBase: Ошибка получения списка пользователей по уровню:', error);
        throw error;
    }
};


// --- Media Functions (PocketBase 'media' collection) ---

// Placeholder/Example validation function - adjust based on your actual media schema
// Now accepts characteristics as an object { key: label }
export const validateMediaData = (mediaData, characteristicsObject) => {
    const errors = [];
    if (!mediaData.get('title')) {
        errors.push('Название обязательно.');
    }
    if (!mediaData.get('type')) {
        errors.push('Тип медиа обязателен.');
    }
     if (!mediaData.get('progress_type')) { // Validate new field
        errors.push('Тип прогресса обязателен.');
    }
    // Add more validation rules as needed based on your schema

    // Validate characteristic count (min 6, max 8) using the passed object
    const charCount = Object.keys(characteristicsObject).length;
    if (charCount < 6 || charCount > 8) {
         errors.push(`Должно быть от 6 до 8 характеристик (сейчас: ${charCount}).`);
    }

    // Validate that characteristic keys are not empty
    for (const key in characteristicsObject) {
        if (!key.trim()) {
            errors.push('Ключ характеристики не может быть пустым.');
            break; // Stop checking keys after finding one empty
        }
    }


    return errors;
};

// Placeholder/Example formatting function - adjust based on your actual media schema
// This function is less critical if you're building FormData correctly in the component
// but can be used for final checks or transformations.
export const formatMediaData = (mediaData) => {
    // Assuming mediaData is already a FormData object prepared in the component
    // You might add default values or transform data here if needed
    // Example: Ensure is_published is boolean
    // if (mediaData.has('is_published')) {
    //     mediaData.set('is_published', mediaData.get('is_published') === 'true');
    // }
    return mediaData; // Return the FormData object
};


// createMedia using FormData
export const createMedia = async (mediaData) => {
  try {
    console.log('PocketBase: Создание медиа:', mediaData);
    // PocketBase create with FormData handles file uploads
    // Ensure mediaData is FormData and includes 'created_by', 'is_published', etc.
    const record = await pb.collection('media').create(mediaData);
    console.log('PocketBase: Медиа создано с ID:', record.id);
    return record;
  } catch (error) {
    console.error('PocketBase: Ошибка создания медиа:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

// Assuming 'path' is a field in your PocketBase 'media' collection
export const getMediaByPath = async (path) => {
  try {
    console.log('PocketBase: Получение медиа по пути:', path);
    // Fetch media record directly, relying on stored average_rating and review_count
    const records = await pb.collection('media').getList(1, 1, {
      filter: `path = "${path}"`,
    });

    if (records.items.length > 0) {
       const item = records.items[0];
       console.log('PocketBase: Медиа найдено по пути:', item);
       console.log('PocketBase: Медиа статистика по пути:', { average_rating: item.average_rating, review_count: item.review_count });
       return item; // Return the media item with stored stats
    } else {
      console.log('PocketBase: Медиа не найдено по пути:', path);
      return null;
    }
  } catch (error) {
    console.error('PocketBase: Ошибка получения медиа по пути:', error);
     if (error.status === 404) { // List returns 200 with empty items, getOne returns 404
        console.log('PocketBase: Медиа не найдено по пути (404):', path);
        return null;
     }
    throw error;
  }
};


export const getMediaById = async (id) => {
  try {
    console.log('PocketBase: Получение медиа по ID:', id);
    // Fetch media record directly, relying on stored average_rating and review_count
    const record = await pb.collection('media').getOne(id);
    console.log('PocketBase: Медиа найдено по ID:', record);
    console.log('PocketBase: Медиа статистика по ID:', { average_rating: record.average_rating, review_count: record.review_count });
    return record; // Return the media item with stored stats

  } catch (error) {
    console.error('PocketBase: Ошибка получения медиа по ID:', error);
     if (error.status === 404) {
        console.log('PocketBase: Медиа не найдено по ID:', id);
        return null;
     }
    throw error;
  }
};

// listMedia using PocketBase pagination and relations
// Added isPopular filter option
// Added 'published' filter option for admin/critic
export const listMedia = async (
    type = null,
    page = 1,
    limit = 20,
    user = null,
    isPopular = false,
    published = true,
    sort = '-created',
    filterString = ''
) => {
  try {
        console.log('[PocketBase] Запрос медиа:', {
            type,
            page,
            limit,
            user,
            isPopular,
            published,
            sort,
            filterString
        });

        let filter = [];

        // Базовые фильтры
        if (published) {
            filter.push('is_published = true');
        }
        
    if (type) {
            filter.push(`type = "${type}"`);
    }

    if (isPopular) {
            filter.push('is_popular = true');
    }

        // Добавляем пользовательские фильтры
        if (filterString) {
            filter.push(`(${filterString})`);
        }

        // Объединяем все фильтры
        const finalFilter = filter.join(' && ');
        console.log('PocketBase: listMedia filter:', finalFilter);

        const response = await pb.collection('media').getList(page, limit, {
            filter: finalFilter,
            sort: sort,
            expand: 'created_by'
        });

        console.log('PocketBase: Получен список медиа:', response.items);
    return {
            data: response.items,
            count: response.totalItems,
            totalPages: response.totalPages
    };
  } catch (error) {
        console.error('[PocketBase] Ошибка получения списка медиа:', error);
    throw error;
  }
};

// New function to list popular media
export const listPopularMedia = async (limit = 10, user = null) => {
    console.log('PocketBase: Получение списка популярных медиа (лимит:', limit, ')');
    // Call listMedia with isPopular = true
    // Pass user to respect published status for non-admins/critics
    return listMedia(null, 1, limit, user, true, true); // Ensure popular media is also published
};


// updateMedia using FormData
export const updateMedia = async (id, mediaData) => {
  try {
    console.log('PocketBase: Обновление медиа:', id, 'с данными:', mediaData);
    // PocketBase update requires the record ID
    // Pass FormData directly if mediaData is FormData
    const record = await pb.collection('media').update(id, mediaData);
    console.log('PocketBase: Медиа обновлено успешно:', record);
    console.log('PocketBase: Обновленная медиа статистика:', { average_rating: record.average_rating, review_count: record.review_count, is_published: record.is_published, is_popular: record.is_popular });
    return record;
  } catch (error) {
    console.error('PocketBase: Ошибка обновления медиа:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

export const deleteMedia = async (id) => {
  try {
    console.log('PocketBase: Удаление медиа:', id);
    // PocketBase delete requires the record ID
    await pb.collection('media').delete(id);
    console.log('PocketBase: Медиа удалено успешно:', id);
    return { success: true }; // Indicate success
  } catch (error) {
    console.error('PocketBase: Ошибка удаления медиа:', error);
    throw error;
  }
};

// This function is now primarily for PocketBase backend hooks/triggers
// The frontend will rely on the stored average_rating and review_count
// Generalized function to update rating stats for any collection (media or seasons)
// MODIFIED: If collectionName is 'media', fetch ALL reviews related to this media_id,
// regardless of whether they have a season_id or not.
export const updateRatingStats = async (collectionName, recordId) => {
  console.log(`PocketBase: Попытка обновления статистики рейтинга для ${collectionName} ID:`, recordId);
  if (!recordId) {
     console.error(`PocketBase: updateRatingStats вызван с undefined ${collectionName}Id`);
     return;
  }
  try {
    let reviewsRecords;
    let filterField;

    if (collectionName === 'media') {
        // For media, fetch ALL reviews where media_id matches
        filterField = 'media_id';
        reviewsRecords = await pb.collection('reviews').getList(1, 500, { // Fetch up to 500 reviews, adjust limit if needed
            filter: `${filterField} = "${recordId}"`,
            fields: 'ratings' // Only fetch the ratings field
        });
    } else if (collectionName === 'seasons') {
        // For seasons, fetch reviews where season_id matches
        filterField = 'season_id';
         reviewsRecords = await pb.collection('reviews').getList(1, 500, { // Fetch up to 500 reviews, adjust limit if needed
            filter: `${filterField} = "${recordId}"`,
            fields: 'ratings' // Only fetch the ratings field
        });
    } else {
        console.error(`PocketBase: Неизвестное имя коллекции для обновления статистики рейтинга: ${collectionName}`);
        return;
    }


    const reviews = reviewsRecords.items;
    const reviewCount = reviews.length;
    let totalApplicableRating = 0;
    let applicableReviewCount = 0; // Count reviews that have at least one applicable rating

    reviews.forEach(review => {
        let reviewTotal = 0;
        let reviewApplicableCount = 0;

        // Ensure review.ratings is an object before iterating
        if (review.ratings && typeof review.ratings === 'object') {
            // Iterate over values and sum them up directly, assuming { [key]: number } structure
            Object.values(review.ratings).forEach(ratingValue => {
                // Only include numeric values
                if (typeof ratingValue === 'number') {
                    reviewTotal += ratingValue;
                    reviewApplicableCount += 1;
                }
            });
        }

        // Only include this review in the overall average if it has at least one applicable rating
        if (reviewApplicableCount > 0) {
            totalApplicableRating += (reviewTotal / reviewApplicableCount); // Add the average of applicable ratings for this review
            applicableReviewCount += 1; // Count this review as applicable
        }
    });


    let averageRating = 0;
    if (applicableReviewCount > 0) {
      averageRating = totalApplicableRating / applicableReviewCount;
    }

    // Update the record in the specified collection with the new stats
    const updatedRecord = await pb.collection(collectionName).update(recordId, {
      average_rating: parseFloat(averageRating.toFixed(2)),
      review_count: reviewCount // review_count is the total number of reviews, regardless of N/A
    });

    console.log(`PocketBase: Средний рейтинг ${collectionName} обновлен для ID:`, recordId, '->', updatedRecord);
    console.log(`PocketBase: Обновленная статистика ${collectionName} (updateRatingStats):`, { average_rating: updatedRecord.average_rating, review_count: updatedRecord.review_count });
    return updatedRecord;

  } catch (error) {
    console.error(`PocketBase: Ошибка обновления среднего рейтинга ${collectionName}:`, error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};


// --- User Review Stats Update ---
const updateUserReviewStats = async (userId) => {
   if (!userId) {
      console.warn('PocketBase: updateUserReviewStats called with undefined userId');
      return;
   }
   console.log('PocketBase: Попытка обновления статистики обзоров для пользователя ID:', userId);
   try {
      // Fetch all reviews by this user
      const reviewsRecords = await pb.collection('reviews').getList(1, 500, { // Fetch up to 500 reviews by user
         filter: `user_id = "${userId}"`,
         fields: 'ratings' // Only fetch the ratings field
      });

      const reviews = reviewsRecords.items;
      const reviewCount = reviews.length;
      let totalApplicableRating = 0;
      let applicableReviewCount = 0; // Count reviews that have at least one applicable rating

      reviews.forEach(review => {
          let reviewTotal = 0;
          let reviewApplicableCount = 0;

          // Ensure review.ratings is an object before iterating
          if (review.ratings && typeof review.ratings === 'object') {
              // Iterate over values and sum them up directly, assuming { [key]: number } structure
              Object.values(review.ratings).forEach(ratingValue => {
                  // Only include numeric values
                  if (typeof ratingValue === 'number') {
                      reviewTotal += ratingValue;
                      reviewApplicableCount += 1;
                  }
              });
          }

          // Only include this review in the overall user average if it has at least one applicable rating
          if (reviewApplicableCount > 0) {
              totalApplicableRating += (reviewTotal / reviewApplicableCount); // Add the average of applicable ratings for this review
              applicableReviewCount += 1; // Count this review as applicable
          }
      });


      let averageRating = 0;
      if (applicableReviewCount > 0) {
         averageRating = totalApplicableRating / applicableReviewCount;
      }

      // Update the user record with the new stats
      const updatedUser = await pb.collection('users').update(userId, {
         average_rating: parseFloat(averageRating.toFixed(2)),
         review_count: reviewCount // review_count is the total number of reviews by the user
      });

      console.log('PocketBase: Статистика обзоров пользователя обновлена для ID:', userId, '->', updatedUser);
      console.log('PocketBase: Обновленная статистика пользователя (updateUserReviewStats):', { average_rating: updatedUser.average_rating, review_count: updatedUser.review_count, xp: updatedUser.xp, level: updatedUser.level }); // Log new fields
      return updatedUser;

   } catch (error) {
      console.error('PocketBase: Ошибка обновления статистики обзоров пользователя:', error);
       if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
      throw error;
   }
};


// --- Review Functions (PocketBase 'reviews' collection) ---
export const getLatestReviews = async (limit = 10) => {
  try {
    console.log('PocketBase: Получение последних обзоров (лимит:', limit, ')');
    // Fetch reviews, sorted by creation date, EXPANDING user_id, media_id, and season_id
    const records = await pb.collection('reviews').getList(1, limit, {
      sort: '-created',
      expand: 'user_id,media_id,season_id' // Use the actual relation field names
    });

    console.log('PocketBase: Получены последние обзоры с expand:', records.items);

    // The items now contain the expanded data in the 'expand' field
    // No need for manual fetching and mapping
    return records.items;

  } catch (error) {
    console.error('PocketBase: Ошибка получения последних обзоров:', error);
    throw error;
  }
};


// Modified to potentially filter by media_id OR season_id
export const getReviewsByMediaId = async (mediaId, seasonId = null, getAllReviews = false) => {
  try {
        console.log('PocketBase: Получение рецензий для медиа:', { mediaId, seasonId, getAllReviews });
        
    let filter = `media_id = "${mediaId}"`;
        
        // Если не запрашиваем все рецензии и указан сезон, добавляем фильтр по сезону
        if (!getAllReviews && seasonId) {
            filter += ` && season_id = "${seasonId}"`;
        }
        
        // Если запрашиваем все рецензии, не добавляем фильтр по сезону
        // Если запрашиваем общие рецензии (seasonId = null), добавляем фильтр season_id = null
        
        const records = await pb.collection('reviews').getList(1, 100, {
      filter: filter,
      sort: '-created',
            expand: 'user_id,media_id,season_id'
    });

        console.log('PocketBase: Получены рецензии:', records.items);
    return records.items;
  } catch (error) {
        console.error('PocketBase: Ошибка при получении рецензий:', error);
    throw error;
  }
};

// New function to get reviews by user ID
export const getReviewsByUserId = async (userId) => {
  try {
    console.log('PocketBase: Получение обзоров для пользователя ID:', userId);
    // Fetch reviews filtered by user_id, sorted by creation date, EXPANDING media_id, user_id, and season_id
    const records = await pb.collection('reviews').getList(1, 500, { // Fetch up to 500 reviews, adjust limit as needed
      filter: `user_id = "${userId}"`,
      sort: '-created',
      expand: 'media_id,user_id,season_id' // Use the actual relation field names
    });

    console.log('PocketBase: Получены обзоры по пользователю ID с expand:', records.items);

    // The items now contain the expanded data in the 'expand' field
    // No need for manual fetching and mapping
    return records.items;

  } catch (error) {
    console.error('PocketBase: Ошибка получения обзоров по пользователю ID:', error);
    throw error;
  }
};


// Modified to potentially get user review for media OR season
export const getUserReviewForMedia = async (userId, mediaId, seasonId = null) => {
  try {
    console.log('PocketBase: Получение обзора пользователя', userId, 'для медиа', mediaId, 'и сезона', seasonId);
    let filter = `user_id = "${userId}" && media_id = "${mediaId}"`;
     if (seasonId) {
        filter += ` && season_id = "${seasonId}"`; // Filter for a specific season
    } else {
        filter += ` && season_id = null`; // Filter for overall media review (no season)
    }

    // Fetch a single review filtered by user_id and media_id (and optionally season_id), EXPANDING user_id, media_id, and season_id
    const records = await pb.collection('reviews').getList(1, 1, {
      filter: filter,
      expand: 'user_id,media_id,season_id' // Use the actual relation field names
    });

    if (records.items.length > 0) {
      const item = records.items[0];
      console.log('PocketBase: Найден обзор пользователя с expand:', item);
       // The item now contains the expanded data in the 'expand' field
       // No need for manual fetching and mapping
       return item;
    } else {
      console.log('PocketBase: Обзор пользователя не найден');
      return null;
    }
  } catch (error) {
    console.error('PocketBase: Ошибка получения обзора пользователя для медиа/сезона:', error);
    throw error;
  }
};

// Fixed XP amount for creating a review
const REVIEW_XP_REWARD = 25;

// Modified to accept season_id
export const createReview = async (reviewData) => {
  try {
    console.log('PocketBase: Создание обзора:', reviewData);

    // Add the current user's ID to the review data
    const currentUser = pb.authStore.model;
    if (!currentUser) {
        throw new Error('User not authenticated to create a review.');
    }

    // Calculate overall_rating from the ratings object, EXCLUDING N/A
    let calculatedOverallRating = 0;
    let applicableRatingCount = 0;
    if (reviewData.ratings && typeof reviewData.ratings === 'object') {
        // Iterate over values and sum them up directly, assuming { [key]: number } structure
        Object.values(reviewData.ratings).forEach(ratingValue => {
             // Only include numeric values
             if (typeof ratingValue === 'number') {
                calculatedOverallRating += ratingValue;
                applicableRatingCount += 1;
            }
        });
    }

    if (applicableRatingCount > 0) {
        calculatedOverallRating = calculatedOverallRating / applicableRatingCount;
    } else {
        // If no applicable ratings, set overall to 0
        calculatedOverallRating = 0;
    }


    const dataToSend = {
        ...reviewData,
        user_id: currentUser.id, // Add the user_id
        overall_rating: parseFloat(calculatedOverallRating.toFixed(2)), // Add calculated overall_rating
        // media_id, season_id, content, ratings, has_spoilers, progress fields are expected in reviewData
    };

    console.log('PocketBase: Данные для создания обзора:', dataToSend);

    // PocketBase create
    const record = await pb.collection('reviews').create(dataToSend);
    console.log('PocketBase: Обзор создан с ID:', record.id);

    // --- Level and XP Logic ---
    // Fetch the user's current XP and level
    const userRecord = await pb.collection('users').getOne(currentUser.id);
    const currentXP = userRecord.xp || 0;
    const newXP = currentXP + REVIEW_XP_REWARD;
    const newLevel = calculateLevel(newXP);

    console.log(`PocketBase: Начисление XP за рецензию. Текущий XP: ${currentXP}, Начислено: ${REVIEW_XP_REWARD}, Новый XP: ${newXP}, Новый уровень: ${newLevel}`);

    // Update the user's XP and level
    await pb.collection('users').update(currentUser.id, {
        xp: newXP,
        level: newLevel
    });
    console.log('PocketBase: XP и уровень пользователя обновлены.');
    // --- End Level and XP Logic ---


    // After creating a review, update the average rating and review count for the associated media OR season
    if (reviewData.season_id) {
        await updateRatingStats('seasons', reviewData.season_id);
        // Also update the parent media's stats based on ALL reviews (including season reviews)
        await updateRatingStats('media', reviewData.media_id);
    } else if (reviewData.media_id) {
        // If it's an overall media review, just update the media stats
        await updateRatingStats('media', reviewData.media_id);
    } else {
        console.warn('PocketBase: Обзор создан без media_id или season_id.');
    }


    // After creating a review, update the user's review stats (average rating and review count)
    // This also implicitly updates the user state in AuthContext via authStore.onChange
    await updateUserReviewStats(currentUser.id);


    return record;
  } catch (error) {
    console.error('PocketBase: Ошибка создания обзора:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

// Modified to accept season_id in reviewData
export const updateReview = async (reviewId, reviewData) => {
  try {
    console.log('PocketBase: Обновление обзора:', reviewId, 'с данными:', reviewData);

    // Calculate overall_rating from the ratings object if it's being updated
    let calculatedOverallRating = undefined; // Use undefined so it's not included if ratings isn't in reviewData
    if (reviewData.ratings && typeof reviewData.ratings === 'object') {
        let totalApplicableRating = 0;
        let applicableRatingCount = 0;
        // Iterate over values and sum them up directly, assuming { [key]: number } structure
        Object.values(reviewData.ratings).forEach(ratingValue => {
             // Only include numeric values
             if (typeof ratingValue === 'number') {
                totalApplicableRating += ratingValue; // Corrected variable name
                applicableRatingCount += 1;
            }
        });

        if (applicableRatingCount > 0) {
            calculatedOverallRating = parseFloat((totalApplicableRating / applicableRatingCount).toFixed(2));
        } else {
             // If no applicable ratings, set overall to 0
             calculatedOverallRating = 0;
        }
    }

    const dataToSend = {
        ...reviewData,
        // Only include overall_rating if it was calculated (i.e., ratings was provided)
        ...(calculatedOverallRating !== undefined && { overall_rating: calculatedOverallRating }),
        // media_id, season_id, content, ratings, has_spoilers, progress fields are expected in reviewData
    };

    console.log('PocketBase: Данные для обновления обзора:', dataToSend);


    // PocketBase update requires the record ID
    const record = await pb.collection('reviews').update(reviewId, dataToSend);
    console.log('PocketBase: Обзор обновлен успешно:', record);

    // After updating a review, update the average rating and review count for the associated media OR season
    // Need media_id/season_id from reviewData or fetch the review first
    const mediaIdToUpdate = reviewData.media_id || record.media_id;
    const seasonIdToUpdate = reviewData.season_id || record.season_id;

    if (seasonIdToUpdate) {
        await updateRatingStats('seasons', seasonIdToUpdate);
        // Also update the parent media's stats based on ALL reviews (including season reviews)
        if (mediaIdToUpdate) {
            await updateRatingStats('media', mediaIdToUpdate);
        }
    } else if (mediaIdToUpdate) {
        // If it's an overall media review, just update the media stats
        await updateRatingStats('media', mediaIdToUpdate);
    } else {
       console.warn('PocketBase: media_id или season_id не найден для обновления статистики после обновления обзора.');
    }


    // After updating a review, update the user's review stats (average rating and review count)
    // XP and Level are NOT updated on review update, only on creation.
    const userIdToUpdate = reviewData.user_id || record.user_id; // Use user_id from update data or the updated record
     if (userIdToUpdate) {
       await updateUserReviewStats(userIdToUpdate);
    } else {
       console.warn('PocketBase: user_id не найден для обновления статистики пользователя после удаления обзора.');
    }


    return record;
  } catch (error) {
    console.error('PocketBase: Ошибка обновления обзора:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

// Modified to accept mediaId (optional, for convenience)
export const deleteReview = async (reviewId, mediaId = null) => {
  try {
    console.log('PocketBase: Удаление обзора:', reviewId);

    // Get the review first to get the user_id, media_id, and season_id before deleting
    const reviewToDelete = await pb.collection('reviews').getOne(reviewId);
    const userIdToUpdate = reviewToDelete?.user_id;
    const mediaIdToUpdate = mediaId || reviewToDelete?.media_id;
    const seasonIdToUpdate = reviewToDelete?.season_id;


    // PocketBase delete requires the record ID
    await pb.collection('reviews').delete(reviewId);
    console.log('PocketBase: Обзор удален успешно:', reviewId);

    // After deleting a review, update the average rating and review count for the associated media OR season
    if (seasonIdToUpdate) {
        await updateRatingStats('seasons', seasonIdToUpdate);
        // Also update the parent media's stats based on ALL reviews (including season reviews)
        if (mediaIdToUpdate) {
            await updateRatingStats('media', mediaIdToUpdate);
        }
    } else if (mediaIdToUpdate) {
       // If it was an overall media review, just update the media stats
       await updateRatingStats('media', mediaIdToUpdate);
    } else {
       console.warn('PocketBase: mediaId или seasonId не найден для обновления среднего рейтинга после удаления обзора.');
    }

    // After deleting a review, update the user's review stats (average rating and review count)
    // XP and Level are NOT decreased on review deletion in this basic implementation.
     if (userIdToUpdate) {
       await updateUserReviewStats(userIdToUpdate);
    } else {
       console.warn('PocketBase: user_id не найден для обновления статистики пользователя после удаления обзора.');
    }


    return true; // Indicate success
  } catch (error) {
    console.error('PocketBase: Ошибка удаления обзора:', error);
    throw error;
  }
};


// --- Achievement Functions ---

/**
 * Fetches all achievements.
 * @returns {Promise<Array<object>>} List of achievement records.
 */
export const getAllAchievements = async () => {
  try {
    console.log('PocketBase: Получение всех достижений');
    const records = await pb.collection('achievements').getFullList({
      sort: 'created', // Or sort by xp_reward, etc.
    });
    console.log('PocketBase: Получены достижения:', records);
    return records;
  } catch (error) {
    console.error('PocketBase: Ошибка получения достижений:', error);
    throw error;
  }
};

/**
 * Fetches achievements for a specific user.
 * @param {string} userId - The ID of the user.
 * @returns {Promise<Array<object>>} List of user_achievement records with expanded achievement data.
 */
export const getUserAchievements = async (userId) => {
  if (!userId) {
    console.warn('PocketBase: getUserAchievements called with undefined userId');
    return [];
  }
  try {
    console.log('PocketBase: Получение достижений пользователя:', userId);
    // Fetch user_achievements records, expanding the 'achievement_id' relation
    const records = await pb.collection('user_achievements').getList(1, 500, { // Fetch up to 500 user achievements
      filter: `user_id = "${userId}"`,
      sort: '-awarded_at', // Sort by when they were awarded
      expand: 'achievement_id' // Expand the related achievement record
    });

    console.log('PocketBase: Получены достижения пользователя с expand:', records.items);

    // The items now contain the expanded data in the 'expand' field
    // e.g., item.expand.achievement_id will be the achievement record
    return records.items;

  } catch (error) {
    console.error('PocketBase: Ошибка получения достижений пользователя:', error);
    throw error;
  }
};

/**
 * Awards an achievement to a user (typically called from admin panel).
 * @param {string} userId - The ID of the user to award.
 * @param {string} achievementId - The ID of the achievement to award.
 * @param {string} [awardedByUserId] - The ID of the admin/moderator awarding it (optional).
 * @returns {Promise<object>} The created user_achievement record.
 */
export const awardAchievement = async (userId, achievementId, awardedByUserId = null) => {
  if (!userId || !achievementId) {
    console.error('PocketBase: awardAchievement called with missing userId or achievementId');
    throw new Error('Missing userId or achievementId');
  }
  try {
    console.log(`PocketBase: Попытка выдать достижение ${achievementId} пользователю ${userId}`);

    // Check if the user already has this achievement to prevent duplicates
    const existing = await pb.collection('user_achievements').getList(1, 1, {
        filter: `user_id = "${userId}" && achievement_id = "${achievementId}"`
    });

    if (existing.items.length > 0) {
        console.log(`PocketBase: Пользователь ${userId} уже имеет достижение ${achievementId}. Пропуск.`);
        return existing.items[0]; // Return the existing record
    }


    // Create the user_achievement record
    const userAchievementRecord = await pb.collection('user_achievements').create({
      user_id: userId,
      achievement_id: achievementId,
      awarded_by: awardedByUserId, // Can be null
      awarded_at: new Date().toISOString(), // Set current time
    });

    console.log('PocketBase: Запись user_achievement создана:', userAchievementRecord);

    // Fetch the achievement details to get the XP reward
    const achievement = await pb.collection('achievements').getOne(achievementId);
    const xpReward = achievement.xp_reward || 0;

    // Fetch the user's current XP and level
    const userRecord = await pb.collection('users').getOne(userId);
    const currentXP = userRecord.xp || 0;
    const newXP = currentXP + xpReward;
    const newLevel = calculateLevel(newXP);

    console.log(`PocketBase: Начисление XP за достижение. Текущий XP: ${currentXP}, Начислено: ${xpReward}, Новый XP: ${newXP}, Новый уровень: ${newLevel}`);

    // Update the user's XP and level
    await pb.collection('users').update(userId, {
        xp: newXP,
        level: newLevel
    });
    console.log('PocketBase: XP и уровень пользователя обновлены после выдачи достижения.');


    return userAchievementRecord;

  } catch (error) {
    console.error('PocketBase: Ошибка при выдаче достижения:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};


// --- PocketBase File Upload Functions ---

/**
 * Uploads a file to a PocketBase collection record.
 * @param {File} file - The file to upload.
 * @param {string} collectionName - The name of the collection ('users', 'media', etc.).
 * @param {string} recordId - The ID of the record to attach the file to.
 * @param {string} fieldName - The name of the file field in the collection ('profile_picture', 'banner_picture', etc.).
 * @returns {Promise<object>} The updated record object.
 * @throws {Error} If the upload fails.
 */
export const uploadFile = async (file, collectionName, recordId, fieldName) => {
  if (!file) {
    console.warn(`PocketBase: No file provided for ${fieldName} upload.`);
    return null; // Or throw an error if file is required
  }

  console.log(`PocketBase: Attempting to upload file for record ${recordId} in collection "${collectionName}" field "${fieldName}"`);

  try {
    // PocketBase file upload is part of updating the record using FormData
    const formData = new FormData();
    formData.append(fieldName, file);

    // Use update to add/replace the file
    const record = await pb.collection(collectionName).update(recordId, formData);

    console.log(`PocketBase: File uploaded successfully for field "${fieldName}". Record updated:`, record);

    // Return the updated record
    return record;

  } catch (error) {
    console.error(`PocketBase: Caught error during ${fieldName} upload process:`, error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

/**
 * Deletes a file from a PocketBase collection record by setting the field to null.
 * @param {string} collectionName - The name of the collection ('users', 'media', etc.).
 * @param {string} recordId - The ID of the record the file is attached to.
 * @param {string} fieldName - The name of the file field ('profile_picture', 'banner_picture', etc.).
 * @returns {Promise<object>} The updated record object.
 * @throws {Error} If the update fails.
 */
export const deleteFile = async (collectionName, recordId, fieldName) => {
   console.log(`PocketBase: Attempting to delete file for record ${recordId} in collection "${collectionName}" field "${fieldName}"`);
   try {
      // To delete a file in PocketBase, you update the record and set the file field to null
      // The JS SDK update method with { fieldName: null } handles this correctly.
      const updateData = {
         [fieldName]: null, // Set the field to null
      };

      const record = await pb.collection(collectionName).update(recordId, updateData);

      console.log(`PocketBase: File reference removed for field "${fieldName}". Record updated:`, record);
      return record;

   } catch (error) {
      console.error(`PocketBase: Caught error during ${fieldName} deletion process:`, error);
       if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

/**
 * Gets the public URL for a file stored in PocketBase.
 * @param {object} record - The PocketBase record object.
 * @param {string} fieldName - The name of the file field ('profile_picture', 'banner_picture', etc.).
 * @param {object} [options] - Optional options for the URL (e.g., thumb).
 * @returns {string|null} The public URL of the file, or null if the field is empty or record is null.
 */
export const getFileUrl = (record, fieldName, options = {}) => {
  if (!record || !record[fieldName]) {
    return null;
  }
  // PocketBase SDK provides a helper to get the file URL
  try {
     // Use pb.getFileUrl with the record, the filename (which is stored in record[fieldName]), and options
     // The fieldName itself holds the filename(s)
     return pb.getFileUrl(record, record[fieldName], options);
  } catch (e) {
     console.error('Error generating file URL:', e);
     return null;
  }
};

// --- Search Function ---
/**
 * Searches the 'media' collection by title and overview.
 * @param {string} query - The search query string.
 * @returns {Promise<Array<object>>} List of matching media records.
 */
export const searchMedia = async (query) => {
  if (!query || query.trim() === '') {
    return [];
  }
  console.log('PocketBase: Поиск медиа по запросу:', query);
  try {
    // PocketBase search is done using filters
    // We can search in 'title' OR 'overview' fields
    // Using '~' operator for case-insensitive search (should be case-insensitive according to PB docs)
    const records = await pb.collection('media').getList(1, 50, { // Limit results to 50 for quick search
      filter: `title ~ "${query}" || overview ~ "${query}"`, // Case-insensitive search using '~'
      sort: '-created', // Optional: sort results
      // You might want to select specific fields to reduce payload size
      // fields: 'id,title,type,path,poster,release_date'
    });

    console.log('PocketBase: Результаты поиска:', records.items);
    return records.items;

  } catch (error) {
    console.error('PocketBase: Ошибка при поиске медиа:', error);
    throw error;
  }
};


// --- Seasons Functions (New 'seasons' collection) ---

// NOTE: You will need to manually create a 'seasons' collection in PocketBase
// with the following fields:
// - media_id (relation to 'media', required)
// - season_number (number, required)
// - title (text, optional)
// - overview (text, optional)
// - release_date (date, optional)
// - poster (file, optional)
// - average_rating (number, default 0)
// - review_count (number, default 0)
// - is_published (bool, default false)
// - created_by (relation to 'users', required)
// - created (datetime)
// - updated (datetime)
// Add appropriate RLS policies for the 'seasons' collection.

/**
 * Fetches all seasons for a given media ID.
 * @param {string} mediaId - The ID of the parent media (series/anime).
 * @returns {Promise<Array<object>>} List of season records.
 */
export const getSeasonsByMediaId = async (mediaId, options = {}) => {
    try {
    console.log('PocketBase: Получение сезонов для медиа:', mediaId);
    const filter = `media_id = "${mediaId}"`;
    
    const queryOptions = {
      filter,
      sort: 'season_number',
      ...options // Добавляем переданные опции (например, expand)
    };

    const records = await pb.collection('seasons').getList(1, 100, queryOptions);
    console.log('PocketBase: Получены сезоны:', records.items);
    return records.items;
  } catch (err) {
    console.error('Error getting seasons by media ID:', err);
    throw err;
    }
};

/**
 * Fetches a specific season by its ID.
 * @param {string} seasonId - The ID of the season.
 * @returns {Promise<object|null>} The season record or null if not found.
 */
export const getSeasonById = async (seasonId) => {
    if (!seasonId) {
        console.warn('PocketBase: getSeasonById called with undefined seasonId');
        return null;
    }
    try {
        console.log('PocketBase: Получение сезона по ID:', seasonId);
        const record = await pb.collection('seasons').getOne(seasonId);
        console.log('PocketBase: Сезон найден по ID:', record);
        return record;
    } catch (error) {
        console.error('PocketBase: Ошибка получения сезона по ID:', error);
         if (error.status === 404) {
            console.log('PocketBase: Сезон не найден по ID:', seasonId);
            return null;
         }
         if (error.response && error.response.data) {
            console.error('PocketBase: Response data:', error.response.data);
        }
        throw error;
    }
};

/**
 * Creates a new season record.
 * @param {FormData} seasonData - FormData containing season data (including files).
 * @returns {Promise<object>} The created season record.
 */
export const createSeason = async (seasonData) => {
  try {
    console.log('PocketBase: Создание сезона:', seasonData);
    // PocketBase create with FormData handles file uploads
    const record = await pb.collection('seasons').create(seasonData);
    console.log('PocketBase: Сезон создан с ID:', record.id);
    return record;
  } catch (error) {
    console.error('PocketBase: Ошибка создания сезона:', error);
     if (error.response && error.response.data) {
        console.error('PocketBase: Response data:', error.response.data);
    }
    throw error;
  }
};

/**
 * Updates an existing season record.
 * @param {string} seasonId - The ID of the season to update.
 * @param {FormData} seasonData - FormData containing updated season data (including files).
 * @returns {Promise<object>} The updated season record.
 */
export const updateSeason = async (seasonId, seasonData) => {
  try {
    console.log('PocketBase: Обновление сезона:', seasonId, 'с данными:', seasonData);
    // PocketBase update requires the record ID
    // Pass FormData directly if seasonData is FormData
    const record = await pb.collection('seasons').update(seasonId, seasonData);
    console.log('PocketBase: Сезон обновлен успешно:', record);
    return record;
  } catch (error) {
    console.error('PocketBase: Ошибка обновления сезона:', error);
     // --- Added Logging ---
     if (error.response) {
        console.error('PocketBase: Response status:', error.response.status);
        console.error('PocketBase: Response data:', error.response.data);
     } else {
        console.error('PocketBase: No response data available.');
     }
     // --- End Added Logging ---
    throw error;
  }
};

/**
 * Deletes a season record.
 * @param {string} seasonId - The ID of the season to delete.
 * @returns {Promise<boolean>} True if successful.
 */
export const deleteSeason = async (seasonId) => {
  try {
    console.log('PocketBase: Удаление сезона:', seasonId);
    // PocketBase delete requires the record ID
    await pb.collection('seasons').delete(seasonId);
    console.log('PocketBase: Сезон удален успешно:', seasonId);
    return true; // Indicate success
  } catch (error) {
    console.error('PocketBase: Ошибка удаления сезона:', error);
     // --- Added Logging ---
     if (error.response) {
        console.error('PocketBase: Response status:', error.response.status);
        console.error('PocketBase: Response data:', error.response.data);
     } else {
        console.error('PocketBase: No response data available.');
     }
     // --- End Added Logging ---
    throw error;
  }
};

/**
 * Fetches all seasons with optional filtering.
 * @param {Object} options - Optional parameters for filtering and sorting.
 * @param {string} options.mediaId - Optional media ID to filter seasons.
 * @param {boolean} options.published - Optional filter for published status.
 * @param {string} options.sort - Optional sort field (default: 'season_number').
 * @returns {Promise<Array<object>>} List of season records.
 */
export const getSeasons = async (options = {}) => {
    try {
        console.log('PocketBase: Получение сезонов с опциями:', options);
        let filter = '';
        
        // Build filter string based on options
        if (options.mediaId) {
            filter += `media_id = "${options.mediaId}"`;
        }
        if (options.published !== undefined) {
            if (filter) filter += ' && ';
            filter += `is_published = ${options.published}`;
        }

        const queryOptions = {
            sort: options.sort || 'season_number',
            expand: 'media_id,created_by'
        };

        if (filter) {
            queryOptions.filter = filter;
        }

        const records = await pb.collection('seasons').getFullList(queryOptions);

        console.log('PocketBase: Получены сезоны:', records);
        return records;
    } catch (error) {
        console.error('PocketBase: Ошибка получения сезонов:', error);
        if (error.response && error.response.data) {
            console.error('PocketBase: Response data:', error.response.data);
        }
        throw error;
    }
};

// Функции для работы с предложениями
export const getSuggestions = async (page = 1, perPage = 20, sort = '-created') => {
  try {
    const records = await pb.collection('suggestions').getList(page, perPage, {
      sort,
      expand: 'user'
    });
    return records.items;
  } catch (error) {
    console.error('Error fetching suggestions:', error);
    throw error;
  }
};

export const getSuggestionById = async (id) => {
  try {
    const record = await pb.collection('suggestions').getOne(id, {
      expand: 'user'
    });
    return record;
  } catch (error) {
    console.error('Error fetching suggestion:', error);
    throw error;
  }
};

export const createSuggestion = async (data) => {
  try {
    const record = await pb.collection('suggestions').create(data);
    return record;
  } catch (error) {
    console.error('Error creating suggestion:', error);
    throw error;
  }
};

export const updateSuggestion = async (id, data) => {
  try {
    const record = await pb.collection('suggestions').update(id, data);
    return record;
  } catch (error) {
    console.error('Error updating suggestion:', error);
    throw error;
  }
};

export const deleteSuggestion = async (id) => {
  try {
    await pb.collection('suggestions').delete(id);
  } catch (error) {
    console.error('Error deleting suggestion:', error);
    throw error;
  }
};

// Функции для работы с пользователями
export const getUsers = async (page = 1, perPage = 20, sort = '-created') => {
  try {
    console.log('PocketBase: Получение списка пользователей');
    const records = await pb.collection('users').getList(page, perPage, {
      sort
    });
    
    console.log('PocketBase: Получены пользователи:', records.items);
    return records.items;
  } catch (error) {
    console.error('PocketBase: Ошибка получения пользователей:', error);
    throw error;
  }
};

export const updateUser = async (userId, data) => {
  try {
    const record = await pb.collection('users').update(userId, data);
    return record;
  } catch (error) {
    console.error('Error updating user:', error);
    throw error;
  }
};

export const deleteUser = async (userId) => {
  try {
    await pb.collection('users').delete(userId);
    return true;
  } catch (error) {
    console.error('Error deleting user:', error);
    throw error;
  }
};

// Export pb instance if needed elsewhere (e.g., for authStore listener)
export { pb };

export const getMediaCount = async () => {
  try {
    const records = await pb.collection('media').getList(1, 1, {
      fields: 'id'
    });
    return records.totalItems;
  } catch (error) {
    console.error('Error getting media count:', error);
    return 0;
  }
};

export const getReviewsCount = async () => {
  try {
    const records = await pb.collection('reviews').getList(1, 1, {
      fields: 'id'
    });
    return records.totalItems;
  } catch (error) {
    console.error('Error getting reviews count:', error);
    return 0;
  }
};

export const getFeaturedMedia = async () => {
  try {
    const records = await pb.collection('media').getList(1, 6, {
      sort: '-rating',
      expand: 'poster'
    });
    return records.items;
  } catch (error) {
    console.error('Error fetching featured media:', error);
    return [];
  }
};

export const getReviewsByLikes = async (limit = 20) => {
    try {
        console.log('PocketBase: Получение рецензий по лайкам (лимит:', limit, ')');
        const records = await pb.collection('reviews').getList(1, 100, {
            expand: 'media_id,user_id'
        });
        
        // Сортируем на клиенте
        const sortedReviews = records.items.sort((a, b) => {
            const aLikes = a.likes?.length || 0;
            const bLikes = b.likes?.length || 0;
            return bLikes - aLikes;
        }).slice(0, limit);

        console.log('PocketBase: Получены рецензии по лайкам:', sortedReviews);
        return sortedReviews;
    } catch (error) {
        console.error('PocketBase: Ошибка получения рецензий по лайкам:', error);
        throw error;
    }
};

export const getAdminStats = async () => {
  try {
    const stats = {
      users: 0,
      media: 0,
      reviews: 0,
      tickets: 0,
      suggestions: 0
    };

    // Получаем количество пользователей
    try {
      const usersCount = await pb.collection('users').getList(1, 1, {
        fields: 'id'
      });
      stats.users = usersCount.totalItems;
    } catch (error) {
      console.warn('Не удалось получить количество пользователей:', error);
    }

    // Получаем количество медиа
    try {
      const mediaCount = await pb.collection('media').getList(1, 1, {
        fields: 'id'
      });
      stats.media = mediaCount.totalItems;
    } catch (error) {
      console.warn('Не удалось получить количество медиа:', error);
    }

    // Получаем количество обзоров
    try {
      const reviewsCount = await pb.collection('reviews').getList(1, 1, {
        fields: 'id'
      });
      stats.reviews = reviewsCount.totalItems;
    } catch (error) {
      console.warn('Не удалось получить количество обзоров:', error);
    }

    // Получаем количество тикетов
    try {
      const ticketsCount = await pb.collection('support_tickets').getList(1, 1, {
        fields: 'id'
      });
      stats.tickets = ticketsCount.totalItems;
    } catch (error) {
      console.warn('Не удалось получить количество тикетов:', error);
    }

    // Получаем количество предложений
    try {
      const suggestionsCount = await pb.collection('suggestions').getList(1, 1, {
        fields: 'id'
      });
      stats.suggestions = suggestionsCount.totalItems;
    } catch (error) {
      console.warn('Не удалось получить количество предложений:', error);
    }

    return stats;
  } catch (error) {
    console.error('Error fetching admin stats:', error);
    throw error;
  }
};
